@@ -18,6 +18,12 @@ from steam_sdk.analyses.custom_analyses.co_simulation_QH_PyBBQ_LEDET_1.utils.cal
 
 def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
 
+    """
+    Function to run a co-simulation for a QH protected magnet including PyBBQ and LEDET
+    :param dict_inputs: Dictionary that contains all variable input variables
+    :return:
+    """
+
     # unpack inputs
     magnet_name = dict_inputs['magnet_name']
     conductor_name = dict_inputs['conductor_name']
@@ -29,6 +35,7 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
     start_adiabatic_calculation = dict_inputs['start_adiabatic_calculation']
     length_initial_hotSpot = dict_inputs['length_initial_hotSpot']
     scaling_vq_initial_hotSpot = dict_inputs['scaling_vq_initial_hotSpot']
+    EE_trigger_time = dict_inputs['EE_trigger_time']
     file_name_analysis_cond = dict_inputs['file_name_analysis_cond']
     file_name_analysis_mag = dict_inputs['file_name_analysis_mag']
     software = dict_inputs['software']
@@ -40,9 +47,38 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
     f_outer_voids = dict_inputs['f_outer_voids']
     simulation_numbers = dict_inputs['simulation_numbers']
 
+    """
+    Adaptable parameters for short model
+    :param magnet_name: Name of the analyzed magnet
+    :param conductor_name: Name of the conductor of the analyzed magnet
+    :param flag_save_MatFile: if set to 2 shorter mat file
+    :param trigger_time_QH: time when the QH are triggered
+    :param QH_strips_active: only containing the QH strips which are active, NUMBERING STARTS FROM 1
+    :param turn_number_quench: number of the turn which should manually quench
+    :param quench_time: time when the manually set quench should occur
+    :param start_adiabatic_calculation: time when the adiabatic hot-spot temperature calculation should start
+    :param length_initial_hotSpot: length of the initial hot-spot
+    :param scaling_vq_initial_hotSpot: vq scaling of the initial quench hot-spot, usually 2
+    :param EE_trigger_time: time when the energy extraction is triggered
+    :param file_name_analysis_cond: name of the conductor analysis file saved in output
+    :param file_name_analysis_mag: name of the magnet analysis file saved in output
+    :param software: used software
+    :param flag_runPyBBQ: flag if PyBBQ should be run
+    :param flag_run_LEDET: flag if LEDET should be run
+    :param current_level: current levels of the magnet
+    :param f_helium: values of wetted_p for the PyBBQ simulation
+    :param f_inner_voids: fraction of inner voids
+    :param f_outer_voids: fraction of inner voids
+    :param simulation_numbers: list of the simulation numbers
+    :param file_path_empty_analysis: path to an empty analysis to initialize aSTEAM (hard coded)
+    """
+
     file_path_empty_analysis = 'Input\\analysis_empty.yaml'
 
     aSTEAM = AnalysisSTEAM(file_name_analysis=file_path_empty_analysis, verbose=True)
+    """
+    Initializing AnalysisSTEAM object for the conductor simulation
+    """
     create_conductor_analysis_file(aSTEAM, conductor_name, flag_save_MatFile, software, current_level, simulation_numbers, f_helium)
 
     ######################## Write output files ########################
@@ -54,6 +90,9 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
 
     if flag_runPyBBQ == 1:
         bSTEAM.run_analysis()
+    """
+    Running conductor simulation
+    """
 
     # Read model_data_magnet file
     model_data_path = os.path.join(Path(aSTEAM.library_path).resolve(), 'magnets', magnet_name, 'input', f'modelData_{magnet_name}.yaml')
@@ -103,6 +142,10 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
     T_bath = all_data_dict_model['GeneralParameters']['T_initial']
     fraction_cover = all_data_dict_model['Quench_Protection']['Quench_Heaters']['f_cover']
 
+    """
+    Loading magnet data
+    """
+
     # getting cable data
     A_CableInsulated = (all_data_dict_model['Conductors'][0]['cable']['bare_cable_width']+all_data_dict_model['Conductors'][0]['cable']['th_insulation_along_width']) * (all_data_dict_model['Conductors'][0]['cable']['bare_cable_height_mean']+all_data_dict_model['Conductors'][0]['cable']['th_insulation_along_height'])
     f_SC = 1/(all_data_dict_model['Conductors'][0]['strand']['Cu_noCu_in_strand']+1)
@@ -133,9 +176,17 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
         Bc20_Nb3Sn = all_data_dict_model['Conductors'][0]['Jc_fit']['Bc20_Summers']
 
     aSTEAM = AnalysisSTEAM(file_name_analysis=file_path_empty_analysis, verbose=True)
+    """
+     Initializing AnalysisSTEAM object for the magnet simulation
+     """
     create_magnet_analysis_file(aSTEAM, magnet_name, software, simulation_numbers)
 
     for i in range(len(simulation_numbers)):
+
+        """
+        Calculation quench propagation scaling
+        """
+
         # initializing scaling_vq, length_HotSpot and timeOfQuench
         scaling_vq = all_data_dict_model['Options_LEDET']['quench_initiation']['fScaling_vQ_iStartQuench']
         scaling_vq = np.ones(len(scaling_vq))
@@ -167,7 +218,7 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
         # calculating fraction of turns covered by heater
         # only active heaters are considered
         for n in range(len(QH_strips_active[i])):
-            QH_trigger_time[QH_strips_active[i][n]-1] = trigger_time_QH
+            QH_trigger_time[QH_strips_active[i][n]-1] = trigger_time_QH[i]
             new_scale_vq = round(2 * vQ_PyBBQ / vQ_analytic * round(heater_length[QH_strips_active[i][n] - 1] / (l_copper[QH_strips_active[i][n] - 1] + l_steel[QH_strips_active[i][n] - 1]), 0), 2)
             new_length_HotSpot = heater_length[QH_strips_active[i][n] - 1] * fraction_cover[QH_strips_active[i][n] - 1]
             for j in range(len(heater_turns)):
@@ -209,6 +260,7 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
                                                                            0])] - 1] = new_length_HotSpot
 
                     # setting the two turns which are physically in contact along the height to quench
+                    # should only used when sure that the quench arrives fast in the next layer
                     # if len(np.where(iContactAlongHeight_From == heater_turns[j])[0]) > 0:
                     #     scaling_vq[iContactAlongHeight_To[np.where(np.in1d(iContactAlongHeight_From, heater_turns[j]))[0]]-1] = new_scale_vq
                     #     length_HotSpot[iContactAlongHeight_To[np.where(np.in1d(iContactAlongHeight_From, heater_turns[j]))[0]]-1] = new_length_HotSpot
@@ -255,7 +307,8 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
             'Options_LEDET.quench_initiation.fScaling_vQ_iStartQuench',
             'Options_LEDET.quench_initiation.tStartQuench',
             "Conductors[0].cable.f_inner_voids",
-            "Conductors[0].cable.f_outer_voids"
+            "Conductors[0].cable.f_outer_voids",
+            'Quench_Protection.Energy_Extraction.t_trigger'
         ]
         aSTEAM.data_analysis.AnalysisStepDefinition[current_step].variables_value = [
             [flag_save_MatFile],
@@ -267,7 +320,8 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
             [scaling_vq],
             [time_of_quench],
             [f_inner_voids[i]],
-            [f_outer_voids[i]]
+            [f_outer_voids[i]],
+            [EE_trigger_time[i]]
             ]
         aSTEAM.data_analysis.AnalysisStepDefinition[current_step].simulation_numbers = [simulation_numbers[i]]
         aSTEAM.data_analysis.AnalysisStepDefinition[current_step].simulation_name = f'{magnet_name}'
@@ -286,5 +340,9 @@ def co_simulation_QH_PyBBQ_LEDET_1(dict_inputs: Dict):
     # Note: To make sure the automatically-generated STEAM analysis yaml file is a valid one, the analysis is run from the yaml file and not from the aSTEAM object
     bSTEAM = AnalysisSTEAM(file_name_analysis=os.path.join(aSTEAM.output_path, file_name_analysis_mag), verbose=True)
 
+    """
+    run magnet simulation
+    """
+
     if flag_run_LEDET == 1:
         bSTEAM.run_analysis()
