@@ -1,3 +1,4 @@
+from steam_sdk.data.DataModelMagnet import DataModelMagnet
 from steam_sdk.data.DataRoxieParser import RoxieData
 from steam_sdk.data.DataFiQuS import DataFiQuS, MultipoleRoxieGeometry, MultipoleSettings, MultipoleConductor
 
@@ -8,7 +9,7 @@ class BuilderFiQuS:
     """
 
     def __init__(self,
-                 model_data,
+                 model_data: DataModelMagnet = None,
                  roxie_data=None,
                  flag_build: bool = True,
                  flag_plot_all: bool = False,
@@ -37,7 +38,9 @@ class BuilderFiQuS:
             if model_data.GeneralParameters.magnet_type == 'multipole':
                 if not roxie_data:
                     raise Exception(f'Cannot build model instantly without providing RoxieData as input roxie_data')
-                self.buildDataMultipole(model_data, roxie_data, flag_plot_all)
+                self.data_FiQuS_geo = MultipoleRoxieGeometry()
+                self.data_FiQuS_set = MultipoleSettings()
+                self.buildDataMultipole(model_data, roxie_data)
             elif model_data.GeneralParameters.magnet_type == 'CCT_straight':
                 self.buildDataCCT(model_data)
             else:
@@ -97,17 +100,15 @@ class BuilderFiQuS:
         for key, value in model_data.Options_FiQuS.cct.postproc.dict().items():       # for keys that are present in the model data and in data FiQuS - they are the same
             self.data_FiQuS.magnet.postproc.__setattr__(key, value)
 
-    def buildDataMultipole(self, model_data, roxie_data, flag_plot_all):
+    def buildDataMultipole(self, model_data, roxie_data):
         """
             Load selected conductor data from DataModelMagnet keys, check inputs, calculate and set missing variables
         """
 
         # geom file
-        self.data_FiQuS_geo = MultipoleRoxieGeometry()
         self.data_FiQuS_geo.Roxie_Data = RoxieData(**roxie_data.dict())
 
         # set file
-        self.data_FiQuS_set = MultipoleSettings()
         self.data_FiQuS_set.Model_Data_GS.general_parameters.I_ref = \
             [model_data.Options_LEDET.field_map_files.Iref] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
         for cond in model_data.Conductors:
@@ -116,6 +117,12 @@ class BuilderFiQuS:
             conductor.cable.bare_cable_width = cond.cable.bare_cable_width
             conductor.cable.bare_cable_height_mean = cond.cable.bare_cable_height_mean
 
+        # --------- run ----------
+        self.data_FiQuS.run = model_data.Options_FiQuS.run
+
+        # --------- general ----------
+        self.data_FiQuS.general.magnet_name = model_data.GeneralParameters.magnet_name
+
         # --------- geometry ----------
         self.data_FiQuS.magnet.geometry = model_data.Options_FiQuS.multipole.geometry
 
@@ -123,9 +130,14 @@ class BuilderFiQuS:
         self.data_FiQuS.magnet.mesh = model_data.Options_FiQuS.multipole.mesh
 
         # ------------- solve -------------
-        self.data_FiQuS.magnet.solve.I_initial = \
-            [model_data.Power_Supply.I_initial] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
+        self.data_FiQuS.magnet.solve.thermal = model_data.Options_FiQuS.multipole.solve.thermal
+        self.data_FiQuS.magnet.solve.thin_shells = model_data.Options_FiQuS.multipole.solve.thin_shells
         self.data_FiQuS.magnet.solve.pro_template = model_data.Options_FiQuS.multipole.solve.pro_template
 
+        self.data_FiQuS.magnet.solve.electromagnetics.solved = model_data.Options_FiQuS.multipole.solve.electromagnetics.solved
+        self.data_FiQuS.magnet.solve.electromagnetics.transient = model_data.Options_FiQuS.multipole.solve.electromagnetics.transient
+        self.data_FiQuS.magnet.solve.electromagnetics.boundary_conditions.currents = \
+            [model_data.Power_Supply.I_initial] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
+
         # ------------- postproc ---------
         self.data_FiQuS.magnet.postproc = model_data.Options_FiQuS.multipole.postproc
