@@ -1,7 +1,7 @@
+import datetime
 import os
 import shutil
 from pathlib import Path
-import pandas as pd
 
 from steam_sdk.builders.BuilderPyBBQ import BuilderPyBBQ
 from steam_sdk.data.DataModelConductor import DataModelConductor
@@ -165,6 +165,10 @@ class BuilderModel:
                     if s == 'LEDET':    self.buildLEDET()
                     if s == 'PyBBQ':    self.buildPyBBQ() # TODO: raise error when wrong software selected?
 
+        # Display time stamp
+        if self.verbose:
+            print(f'BuilderModel ended. Time stamp: {datetime.datetime.now()}')
+
     def set_input_paths(self):
         """
             Sets input paths from created DataModel, set path to usersettings and displays related information
