@@ -1,6 +1,5 @@
 import os
 from pathlib import Path
-import yaml
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
@@ -9,7 +8,7 @@ from steam_sdk.wrappers.java.SIGMA import WrapperSIGMA as ws
 from steam_sdk.plotters import PlotterSIGMA as p
 from steam_sdk.data import DataRoxieParser as dR
 from steam_sdk.data.DataModelMagnet import DataModelMagnet
-
+from steam_sdk.parsers.ParserRoxie import arcCenter
 
 class BuilderSIGMA:
     """
@@ -50,14 +49,16 @@ class BuilderSIGMA:
             self.show_halfTurns = True  # to be provided by the yaml in the future
             self.model_name = f"{self.model_data.GeneralParameters.magnet_name}_Model"
 
-            self.bh_curve_database = os.path.join(Path(__file__).parent.parent.parent.parent,
-                                                  "steam_models", "magnets", "bh_curve_database.txt")
+            self.bh_curve_database = os.path.join(Path(__file__).parent.parent.parent,
+                                                  "tests", "builders", "model_library", "magnets", "bh_curve_database.txt")
 
-            self.COMSOL_exe_path = self.settings_dict['comsolexe_path']
+
+            self.COMSOL_exe_path = Path(self.settings_dict['comsolexe_path']).parent
             self.java_jdk_path = self.settings_dict['JAVA_jdk_path']
 
-            self.COMSOL_compile_path = f"{self.COMSOL_exe_path[:-4]}compile.exe"
-            self.COMSOL_batch_path = f"{self.COMSOL_exe_path[:-4]}batch.exe"
+            self.COMSOL_compile_path = os.path.join(self.COMSOL_exe_path, 'comsolcompile.exe')  # Change os.join()
+            self.COMSOL_batch_path = os.path.join(self.COMSOL_exe_path, 'comsolbatch.exe')
+            print(self.COMSOL_batch_path)
 
             self.model_java_file_path = f"{os.path.join(self.output_path, self.model_name)}.java"
             self.compile_batch_file_path = f"{os.path.join(self.output_path, self.model_name)}_Compile_and_Open.bat"
@@ -67,7 +68,7 @@ class BuilderSIGMA:
             self.build_magnet()
             self.save_model_java()
             self.save_compile_and_open_bat()
-            self.plot_magnet()
+            # self.plot_magnet()
 
     def build_magnet(self):
         self.air_ff_domain()
@@ -240,17 +241,21 @@ class BuilderSIGMA:
                         currents = ()
                         for block_key, block in winding.blocks.items():
                             currents += (block.current_sign,)
-                            kp0 = self.g.Point.ofCartesian(coil.bore_center.x, coil.bore_center.y)
-                            arg = [self.g.Point.ofCartesian(block.block_corners.iL.x, block.block_corners.iL.y),
-                                   self.g.Point.ofCartesian(block.block_corners.iR.x, block.block_corners.iR.y),
-                                   self.g.Point.ofCartesian(block.block_corners.oR.x, block.block_corners.oR.y),
-                                   self.g.Point.ofCartesian(block.block_corners.oL.x, block.block_corners.oL.y)]
-
+                            # kp0 = self.g.Point.ofCartesian(coil.bore_center.x, coil.bore_center.y)
+                            bore = coil.bore_center
+                            inner, outer = arcCenter(bore, block.block_corners.iH, block.block_corners.oH
+                                                     , block.block_corners.iLA, block.block_corners.oLA, diff_radius=None)
+                            arg = [self.g.Point.ofCartesian(block.block_corners.iH.x, block.block_corners.iH.y),
+                                   self.g.Point.ofCartesian(block.block_corners.iLA.x, block.block_corners.iLA.y),
+                                   self.g.Point.ofCartesian(block.block_corners.oLA.x, block.block_corners.oLA.y),
+                                   self.g.Point.ofCartesian(block.block_corners.oH.x, block.block_corners.oH.y)]
+                            kp0_inner = self.g.Point.ofCartesian(inner[0], inner[1])
+                            kp0_outer = self.g.Point.ofCartesian(outer[0], outer[1])
                             areas += (self.g.Area.ofHyperLines(
                                 self.a.create_hyper_line_array(self.g.gateway,
-                                                               (self.g.Arc.ofEndPointsCenter(arg[0], arg[1], kp0),
+                                                               (self.g.Arc.ofEndPointsCenter(arg[1], arg[0], kp0_inner),
                                                                 self.g.Line.ofEndPoints(arg[1], arg[3]),
-                                                                self.g.Arc.ofEndPointsCenter(arg[3], arg[2], kp0),
+                                                                self.g.Arc.ofEndPointsCenter(arg[2], arg[3], kp0_outer),
                                                                 self.g.Line.ofEndPoints(arg[0], arg[2])))),)
                         self.coil_areas += [areas[0], areas[1]]
 
@@ -280,10 +285,10 @@ class BuilderSIGMA:
         for i in wedges:
             kp0_inner = self.g.Point.ofCartesian(wedges[i].corrected_center.inner.x, wedges[i].corrected_center.inner.y)
             kp0_outer = self.g.Point.ofCartesian(wedges[i].corrected_center.outer.x, wedges[i].corrected_center.outer.y)
-            arg = [self.g.Point.ofCartesian(wedges[i].corners.iL.x, wedges[i].corners.iL.y),
-                   self.g.Point.ofCartesian(wedges[i].corners.iR.x, wedges[i].corners.iR.y),
-                   self.g.Point.ofCartesian(wedges[i].corners.oL.x, wedges[i].corners.oL.y),
-                   self.g.Point.ofCartesian(wedges[i].corners.oR.x, wedges[i].corners.oR.y)]
+            arg = [self.g.Point.ofCartesian(wedges[i].corners.iH.x, wedges[i].corners.iH.y),
+                   self.g.Point.ofCartesian(wedges[i].corners.iLA.x, wedges[i].corners.iLA.y),
+                   self.g.Point.ofCartesian(wedges[i].corners.oH.x, wedges[i].corners.oH.y),
+                   self.g.Point.ofCartesian(wedges[i].corners.oLA.x, wedges[i].corners.oLA.y)]
 
             area = self.g.Area.ofHyperLines(self.a.create_hyper_line_array(
                 self.g.gateway, (self.g.Arc.ofEndPointsCenter(arg[0], arg[1], kp0_inner),
@@ -315,7 +320,6 @@ class BuilderSIGMA:
             self.g.IronDomain(i, self.bh_curve_database, self.roxie_data.iron.hyper_areas[i].material, self.elements[i])
             for i in orderedElements]  # domains
         domains += self.iron_yoke
-
         domains.append(self.g.CoilDomain("CO", self.g.MatDatabase.MAT_COIL, self.coil))
 
         domains.append(self.g.WedgeDomain("W", self.g.MatDatabase.MAT_COPPER, self.wedge_elements))
@@ -325,15 +329,20 @@ class BuilderSIGMA:
 
         cfg.setOutputModelPath(self.model_java_file_path)
         cfg.setExternalCFunLibPath(self.settings_dict['CFunLibPath'])
-
+        print(self.settings_dict['CFunLibPath'])
+        cfg.setCOMSOLBatchPath(self.settings_dict['comsolexe_path'])
+        cfg.setCOMSOLCompilePath =self.COMSOL_compile_path
         srv = self.g.TxtSigmaServer(cfg.getOutputModelPath(), cfg.getComsolBatchPath())
         srv.connect(cfg.getComsolBatchPath())
+        print(cfg.getComsolBatchPath())
         self.model = self.g.MagnetMPHBuilder(cfg, srv)
         # Create map with I0.
         variable_map = self.g.gateway.jvm.java.util.HashMap()
         variable_map.put("I_0", f"{self.model_data.Options_SIGMA.simulation.conductor_current}[A]")
         self.model.buildMPH(self.a.create_domain_array(self.g.gateway, tuple(domains)), self.input_coordinates_path,
-                            self.result_txt_path, self.generate_study, variable_map, 4, 1)
+                            self.result_txt_path, self.generate_study, variable_map,
+                            self.model_data.Options_SIGMA.simulation.nbr_elements_mesh_width,
+                            self.model_data.Options_SIGMA.simulation.nbr_elements_mesh_height)
         self.model.save()
 
         with open(self.model_java_file_path) as java_file:
@@ -403,15 +412,14 @@ class BuilderSIGMA:
                         for winding_key, winding in layer.windings.items():
                             for block_key, block in winding.blocks.items():
                                 for halfTurn_nr, halfTurn in block.half_turns.items():
-                                    iL = halfTurn.corners.insulated.iL
-                                    iR = halfTurn.corners.insulated.iR
-                                    oL = halfTurn.corners.insulated.oL
-                                    oR = halfTurn.corners.insulated.oR
+                                    iL = halfTurn.corners.insulated.iH
+                                    iR = halfTurn.corners.insulated.iLA
+                                    oL = halfTurn.corners.insulated.oH
+                                    oR = halfTurn.corners.insulated.oLA
                                     ax.add_line(lines.Line2D([iL.x, iR.x], [iL.y, iR.y], color='red'))
                                     ax.add_line(lines.Line2D([oL.x, oR.x], [oL.y, oR.y], color='red'))
                                     ax.add_line(lines.Line2D([oR.x, iR.x], [oR.y, iR.y], color='red'))
                                     ax.add_line(lines.Line2D([iL.x, oL.x], [iL.y, oL.y], color='red'))
-
         p.plot_multiple_areas(ax, self.coil_areas)
         # p.plot_multiple_areas(ax, self.wedge_areas, color='blue')
         # #
@@ -446,105 +454,4 @@ class BuilderSIGMA:
             f'-outputfile "{os.path.join(self.output_path, self.model_data.GeneralParameters.magnet_name)}.mph"']
 
         with open(self.compile_batch_file_path, "w") as outfile:
-            outfile.write("\n".join(str(line) for line in script_lines))
-
-
-def create_coordinate_file(path_map2d, coordinate_file_path):
-    df = pd.read_csv(path_map2d, delim_whitespace=True)
-    df_new = pd.DataFrame()
-    df_new["X-POS/MM"] = df["X-POS/MM"].apply(lambda x: x / 1000)
-    df_new["Y-POS/MM"] = df["Y-POS/MM"].apply(lambda x: x / 1000)
-    df_new.to_csv(coordinate_file_path, header=None, index=False)
-
-
-def create_result_map2d(path_map2d, path_result, path_new_file):
-    df_reference = pd.read_csv(path_map2d, delim_whitespace=True)
-    with open(path_result) as file:  # opens a text file
-        lines = [line.strip().split() for line in file if not "%" in line]  # loops over each line
-
-    df_txt = pd.DataFrame(lines, columns=["x", "y", "Bx", "By"])
-    df_txt = df_txt.apply(pd.to_numeric)
-    with open(path_new_file, 'w') as file:
-        file.write("  BL.   COND.    NO.    X-POS/MM     Y-POS/MM    BX/T       BY/T"
-                   "      AREA/MM**2 CURRENT FILL FAC.\n\n")
-        content = []
-        for index, row in df_reference.iterrows():
-            bl, cond, no, x, y, Bx, By, area, curr, fill, fac = row
-            bl = int(bl)
-            cond = int(cond)
-            no = int(no)
-            x = f"{x:.4f}"
-            y = f"{y:.4f}"
-            Bx = df_txt["Bx"].iloc[index]
-            Bx = f"{Bx:.4f}"
-            By = df_txt["By"].iloc[index]
-            By = f"{By:.4f}"
-            area = f"{area:.4f}"
-            curr = f"{curr:.2f}"
-            fill = f"{fill:.4f}"
-            content.append(
-                "{0:>6}{1:>6}{2:>7}{3:>13}{4:>13}{5:>11}{6:>11}{7:>11}{8:>9}{9:>8}\n".format(bl, cond, no, x, y, Bx, By,
-                                                                                             area, curr, fill))
-        file.writelines(content)
-
-
-if __name__ == "__main__":
-    from steam_sdk.parsers.ParserRoxie import ParserRoxie
-
-    magnet_name = 'MQXA'  # 'MBH_2in1'  #'MQXA'  #'MBX'  #'MQXB'   # 'MQXF_V2'  #
-    current_path = Path(__file__).parent
-    path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'model_library',
-                         'magnets', magnet_name, 'input')
-    file_model_data = Path.joinpath(path, 'modelData_' + magnet_name + '.yaml')
-    init_dir = os.getcwd()
-    if Path.exists(file_model_data):
-        with open(file_model_data, "r") as stream:
-            dictionary_yaml = yaml.safe_load(stream)
-            model_data = DataModelMagnet(**dictionary_yaml)
-        if model_data.Sources.iron_fromROXIE:
-            path_iron = Path.joinpath(path, model_data.Sources.iron_fromROXIE)
-        else:
-            path_iron = None
-        path_data = Path.joinpath(path, model_data.Sources.coil_fromROXIE)
-    else:
-        path_iron = None
-        path_data = Path.joinpath(path, f"{magnet_name}.data")
-    path_cadata = Path.joinpath(path.parent.parent, 'roxie.cadata')
-
-    working_dir_path = os.path.join(init_dir, magnet_name)
-    # Check if folder exists:
-    if os.path.exists(working_dir_path):
-        print("Directory already exists.")
-    else:
-        os.mkdir(working_dir_path)
-    roxie_parser = ParserRoxie()
-    roxie_data = roxie_parser.getData(dir_data=path_data, dir_cadata=path_cadata, dir_iron=path_iron)
-
-    # with open('../tests/parsers/references/cadata_REFERENCE.yaml', 'w') as yaml_file:
-    #   yaml.dump(roxie_data.conductor.dict(), yaml_file, default_flow_style=False, sort_keys=False)
-    for environ_var in ['HOMEPATH', 'SWAN_HOME']:
-        if environ_var in os.environ:
-            user_name = os.path.basename(os.path.normpath(os.environ[environ_var]))
-    path_sdk = Path(__file__).parent.parent.parent.parent
-    path_settings = Path.joinpath(path_sdk, "steam_models", "settings", "user_settings")
-    if Path.exists(Path.joinpath(path_settings, f"settings.{user_name}.yaml")):
-        with open(Path.joinpath(path_settings, f"settings.{user_name}.yaml"), 'r') as stream:
-            settings = yaml.safe_load(stream)
-
-    os.chdir(working_dir_path)
-    # Create coordinate file from map2d.
-    map2d_path = os.path.join(path, f"{magnet_name}.map2d")
-    coordinate_file_path = (os.path.join(working_dir_path, f"{magnet_name}_coordinates.csv")).replace("\\", "\\\\\\\\")
-    create_coordinate_file(map2d_path, coordinate_file_path)
-    result_txt_path = (os.path.join(working_dir_path, f"{magnet_name}.txt")).replace("\\", "\\\\\\\\")
-
-    bs = BuilderSIGMA(settings_dict=settings, input_model_data=model_data, input_roxie_data=roxie_data,
-                      generate_study=model_data.Options_SIGMA.simulation.generate_study,
-                      coordinate_file_path=coordinate_file_path, result_txt_path=result_txt_path)
-    if model_data.Options_SIGMA.simulation.run_study:
-        os.system(os.path.join(working_dir_path, f"{magnet_name}_Model_Compile_and_Open.bat"))
-    create_result_map2d(map2d_path, result_txt_path, os.path.join(working_dir_path, f"{magnet_name}.map2d"))
-    if model_data.Options_SIGMA.simulation.generate_report:
-        p.plot_roxie_coil(roxie_data)
-        p.generate_report_from_map2d(os.path.join(working_dir_path, f"{magnet_name}.map2d"), f"{magnet_name}_comsol",
-                                 map2d_path, f"{magnet_name}_roxie")
+            outfile.write("\n".join(str(line) for line in script_lines))
\ No newline at end of file
