@@ -15,9 +15,8 @@ def rotatePoint(point, origin, rotation_angle):
         :type point: tuple
         :param origin: 2-element tuple with x/y coordinates of the point around which to rotate
         :type origin: tuple
-        :param angle: rotation angle in radians
-        :type angle: float
-
+        :param rotation_angle: rotation angle in radians
+        :type rotation_angle: float
 
         :return: tuple
     """
@@ -30,7 +29,7 @@ def rotatePoint(point, origin, rotation_angle):
     xRotated = x0 + (x - x0) * math.cos(rotation_angle) - (y - y0) * math.sin(rotation_angle)
     yRotated = y0 + (x - x0) * math.sin(rotation_angle) + (y - y0) * math.cos(rotation_angle)
 
-    return (xRotated, yRotated)
+    return xRotated, yRotated
 
 
 def mirrorPointAboutLine(point, line):
@@ -220,6 +219,7 @@ def close_pairs_ckdtree(X, max_distance):
 
     return np.array(list(pairs))
 
+
 def condensed_to_pair_indices(n, k):
     x = n - (4. * n ** 2 - 4 * n - 8 * k + 1) ** .5 / 2 - .5
     i = x.astype(int)
