@@ -153,6 +153,9 @@ class RunViewer(BaseModel):
     flag_analyze: bool = None
     flag_display: bool = None
     flag_save_figures: bool = None
+    path_output_html_report: str = None
+    path_output_pdf_report: str = None
+    figure_types: Union[List[str], str] = []
     verbose: bool = None
 
 
@@ -189,9 +192,57 @@ class WriteStimulusFile(BaseModel):
     current_level: List[int] = []
     magnets: List[int] = []
     t_offset: List[float] = []
+    interpolation_type: str = None  # 'Linear' or 'Spline'
+    type_file_writing: str = None  # 'w' or 'a'
+    n_sampling: int = None
     magnet_types: List[int] = []
 
 
+class ParsimEvent(BaseModel):
+    """
+        Level 2: Analysis step to write stimulus file from coil resistance csv file
+    """
+    type: Literal['ParsimEvent']
+    input_file: str = None
+    path_output_event_csv: str = None
+    path_output_viewer_csv: Union[List[str], str] = None  # This list must have the same number of elements as the software list
+    simulation_numbers: List[int] = []
+    model_name: str = None
+    case_model: str = None
+    simulation_name: str = None
+    software: List[str] = []
+    t_PC_off: float = None  # TODO: consider making list of floats
+    rel_quench_heater_trip_threshold: float = None
+    current_polarities_CLIQ: List[int] = []  # TODO: consider making list of lists
+    dict_QH_circuits_to_QH_strips: Dict[str, List[int]] = {}
+    default_keys: Dict = {}  # TODO Consider making this a dataclass
+
+
+class ParametricSweep(BaseModel):
+    """
+        Level 2: Analysis step to write stimulus file from sweep input csv file
+    """
+    type: Literal['ParametricSweep']
+    input_sweep_file: str = None
+    model_name: str = None
+    case_model: str = None
+    software: List[str] = []
+    verbose: bool = None
+
+
+class ParsimConductor(BaseModel):
+    """
+        Level 2: Analysis step to write stimulus file from coil csv file
+    """
+    type: Literal['ParsimConductor']
+    model_name: str = None
+    case_model: str = None
+    input_file: str = None
+    software: List[str] = []
+    simulation_number: int = None
+    groups_to_coils: Dict[str, List[int]] = {}  # TODO: keys have to match Coil names in input file
+    path_output_sweeper_csv: str = None
+
 # class AnalysisStep(BaseModel):
 #     """
 #         Level 1: Class for information on the analysis step
@@ -220,5 +271,6 @@ class DataAnalysis(BaseModel):
     WorkingFolders: WorkingFolders = WorkingFolders()
     AnalysisStepDefinition: Dict[str, Union[MakeModel, ModifyModel, ModifyModelMultipleVariables, SetUpFolder,
                                             AddAuxiliaryFile, CopyFile, RunSimulation, PostProcess, RunCustomPyFunction,
-                                            RunViewer, CalculateMetrics, LoadCircuitParameters, WriteStimulusFile]] = {}
+                                            RunViewer, CalculateMetrics, LoadCircuitParameters, WriteStimulusFile,
+                                            ParsimEvent, ParametricSweep, ParsimConductor]] = {}
     AnalysisStepSequence: List[str] = []  # Here the analysis steps are defined, in execution order. Names must be defined in AnalysisStepDefinition. Repetitions ARE allowed.
