@@ -6,6 +6,7 @@ from steam_sdk.data.DataModelMagnet import MeshCCT
 from steam_sdk.data.DataModelMagnet import Air_g
 from steam_sdk.data.DataModelMagnet import MultipoleGeometry
 from steam_sdk.data.DataModelMagnet import MultipoleMesh
+from steam_sdk.data.DataModelMagnet import MultipoleSolve
 from steam_sdk.data.DataModelMagnet import MultipolePostProc
 
 
@@ -57,12 +58,7 @@ class MultipoleModelDataSetting(BaseModel):
     general_parameters: MultipoleGeneralSetting = MultipoleGeneralSetting()
     conductors: Dict[str, MultipoleConductor] = {}
 
-
-class MultipoleSettings(BaseModel):
-    """
-        Class for FiQuS multipole settings (.set)
-    """
-    Model_Data_GS: MultipoleModelDataSetting = MultipoleModelDataSetting()
+#######################################################################################################################
 
 
 class MultipoleRoxieGeometry(BaseModel):
@@ -72,10 +68,15 @@ class MultipoleRoxieGeometry(BaseModel):
     Roxie_Data: RoxieData = RoxieData()
 
 
+class MultipoleSettings(BaseModel):
+    """
+        Class for FiQuS multipole settings (.set)
+    """
+    Model_Data_GS: MultipoleModelDataSetting = MultipoleModelDataSetting()
+
+
 # Modified classes with respect to Options_FiQuS.multipole
-class MultipoleSolve(BaseModel):
-    I_initial: List[float] = None
-    pro_template: str = None  # file name of .pro template file
+
 ############################
 
 
@@ -122,6 +123,7 @@ class FQPL_g(BaseModel):
     z_starts: List[str] = None  # which air boundary to start at. These is string with either: z_min or z_max key from the Air region.
     z_ends: List[float] = None  # z coordinate of loop end
 
+
 class CCTGeometry(BaseModel):
     """
         Level 2: Class for FiQuS CCT for FiQuS input
@@ -131,6 +133,7 @@ class CCTGeometry(BaseModel):
     formers: CCTFormerG = CCTFormerG()
     air: Air_g = Air_g()
 
+
 class Winding_s(BaseModel):  # Solution time used windings _inputs (materials and BC)
     """
         Level 2: Class for FiQuS CCT
@@ -139,6 +142,7 @@ class Winding_s(BaseModel):  # Solution time used windings _inputs (materials an
     sigmas: List[float] = None  # electrical conductivity
     mu_rs: List[float] = None  # relative permeability
 
+
 class FQPL_s(BaseModel):  # Solution time used windings _inputs (materials and BC)
     """
         Level 2: Class for FiQuS CCT
@@ -147,6 +151,7 @@ class FQPL_s(BaseModel):  # Solution time used windings _inputs (materials and B
     sigmas: List[float] = None  # electrical conductivity
     mu_rs: List[float] = None  # relative permeability
 
+
 class Former_s(BaseModel):  # Solution time used formers _inputs (materials and BC)
     """
         Level 2: Class for FiQuS CCT
@@ -154,6 +159,7 @@ class Former_s(BaseModel):  # Solution time used formers _inputs (materials and
     sigmas: List[float] = None  # electrical conductivity
     mu_rs: List[float] = None  # relative permeability
 
+
 class Air_s(BaseModel):  # Solution time used air _inputs (materials and BC)
     """
         Level 2: Class for FiQuS CCT
@@ -161,6 +167,7 @@ class Air_s(BaseModel):  # Solution time used air _inputs (materials and BC)
     sigma: float = None  # electrical conductivity
     mu_r: float = None  # relative permeability
 
+
 class SolveCCT(BaseModel):
     """
         Level 2: Class for FiQuS CCT
@@ -174,6 +181,7 @@ class SolveCCT(BaseModel):
     volumes: List[str] = None  # Name of volume to post-process by GetDP, line Winding_1
     file_exts: List[str] = None  # Name of file extensions to post-process by GetDP, like .pos
 
+
 class CCTPostproc(BaseModel):
     """
         Class for FiQuS CCT input file
