@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from typing import (List, Union)
+from typing import (List, Dict, Union)
 
 from steam_sdk.data.DataConductor import Conductor
 
@@ -294,9 +294,94 @@ class QuenchInitializationBBQ(BaseModel):
 # FiQuS options
 
 # Multipole
+class ConvectionBoundaryCondition(BaseModel):
+    """
+        Level 5: Class for FiQuS Multipole
+    """
+    boundaries: List[str] = []
+    heat_transfer_coefficient: float = None
+    coolant_temperature: float = None
+
+
+class OneParBoundaryCondition(BaseModel):
+    """
+        Level 5: Class for FiQuS Multipole
+    """
+    boundaries: List[str] = []
+    value: float = None
+
+
+class TimeParameters(BaseModel):
+    """
+        Level 5: Class for FiQuS Multipole
+    """
+    initial_time: float = None
+    final_time: float = None
+    time_step: float = None
+
+
+class QuenchInitiation(BaseModel):
+    """
+        Level 5: Class for FiQuS Multipole
+    """
+    turns: List[int] = []
+    temperatures: List[float] = []
+
+
+class BoundaryConditionsElectromagnetics(BaseModel):
+    """
+        Level 4: Class for FiQuS Multipole
+    """
+    currents: List[float] = []
+
+
+class BoundaryConditionsThermal(BaseModel):
+    """
+        Level 4: Class for FiQuS Multipole
+    """
+    temperature: Dict[str, OneParBoundaryCondition] = {}
+    heat_flux: Dict[str, OneParBoundaryCondition] = {}
+    cooling: Dict[str, ConvectionBoundaryCondition] = {}
+
+
+class TransientElectromagnetics(BaseModel):
+    """
+        Level 4: Class for FiQuS Multipole
+    """
+    time_pars: TimeParameters = TimeParameters()
+    initial_current: float = None
+
+
+class TransientThermal(BaseModel):
+    """
+        Level 4: Class for FiQuS Multipole
+    """
+    time_pars: TimeParameters = TimeParameters()
+    initial_temperature: float = None
+    quench_initiation: QuenchInitiation = QuenchInitiation()
+
+
+class Electromagnetics(BaseModel):
+    """
+        Level 3: Class for FiQuS Multipole
+    """
+    solved: str = None
+    boundary_conditions: BoundaryConditionsElectromagnetics = BoundaryConditionsElectromagnetics()
+    transient: TransientElectromagnetics = TransientElectromagnetics()
+
+
+class Thermal(BaseModel):
+    """
+        Level 3: Class for FiQuS Multipole
+    """
+    solved: str = None
+    boundary_conditions: BoundaryConditionsThermal = BoundaryConditionsThermal()
+    transient: TransientThermal = TransientThermal()
+
+
 class Threshold(BaseModel):
     """
-        Level 2: Class for FiQuS Multipole
+        Level 3: Class for FiQuS Multipole
     """
     SizeMin: float = None
     SizeMax: float = None
@@ -309,6 +394,7 @@ class MultipoleGeometry(BaseModel):
         Level 2: Class for FiQuS Multipole
     """
     with_iron_yoke: bool = None
+    with_wedges: bool = None
 
 
 class MultipoleMesh(BaseModel):
@@ -331,6 +417,9 @@ class MultipoleSolve(BaseModel):
     """
         Level 2: Class for FiQuS Multipole
     """
+    electromagnetics: Electromagnetics = Electromagnetics()
+    thermal: Thermal = Thermal()
+    thin_shells: bool = None
     pro_template: str = None  # file name of .pro template file
 
 
