@@ -261,10 +261,10 @@ class Corner(BaseModel):
     """
         Class for corner positions
     """
-    iL: Coord = Coord()  # inner left
-    iR: Coord = Coord()  # inner right
-    oL: Coord = Coord()  # outer left
-    oR: Coord = Coord()  # outer right
+    iH: Coord = Coord()  # inner left
+    iLA: Coord = Coord()  # inner right
+    oH: Coord = Coord()  # outer left
+    oLA: Coord = Coord()  # outer right
 
 
 class HalfTurnCorner(BaseModel):
@@ -356,7 +356,7 @@ class CoilData(BaseModel):
         Class for coils
     """
     coils: Dict[int, Pole] = {}
-    electrical_order: List[Order] = []
+    physical_order: List[Order] = []
 
 
 class RoxieRawData(BaseModel):
