@@ -13,7 +13,7 @@ class DataSettings(BaseModel):
     COSIM_path:          str = None  #
     Dakota_path:         str = None  #
     FiQuS_path:          str = None  #
-    #FiQuS_GetDP_path:    str = None  # full path to CERN GetDP build executable
+    GetDP_path:          str = None  # full path to CERN GetDP build executable
     LEDET_path:          str = None  #
     ProteCCT_path:       str = None  #
     PSPICE_path:         str = None  #
