@@ -6,16 +6,18 @@ class DriverFiQuS:
     """
         Class to drive FiQuS models
     """
-    def __init__(self, FiQuS_path='', path_folder_FiQuS=None, path_folder_FiQuS_input=None, verbose=False):
+    def __init__(self, FiQuS_path='', path_folder_FiQuS=None, path_folder_FiQuS_input=None, verbose=False, GetDP_path=None):
         self.FiQuS_path = FiQuS_path
         self.path_folder_FiQuS = path_folder_FiQuS
         self.path_folder_FiQuS_input = path_folder_FiQuS_input
         self.verbose = verbose
+        self.GetDP_path = GetDP_path
         if verbose:
             print('path_exe =          {}'.format(FiQuS_path))
             print('path_folder_FiQuS = {}'.format(path_folder_FiQuS))
 
-        sys.path.insert(0, FiQuS_path)
+        if FiQuS_path !='pypi':
+            sys.path.insert(0, FiQuS_path)
         from fiqus.MainFiQuS import MainFiQuS as MF
         self.MainFiQuS = MF
 
@@ -24,6 +26,6 @@ class DriverFiQuS:
         full_path_output = os.path.join(self.path_folder_FiQuS, output_directory)
 
         # Run model
-        return self.MainFiQuS(input_file_path=full_path_input, model_folder=full_path_output).summary
+        return self.MainFiQuS(input_file_path=full_path_input, model_folder=full_path_output, GetDP_path=self.GetDP_path).summary
         # return subprocess.call(['py', self.path_exe, model_data_path, outputDirectory])
 
