@@ -1,20 +1,24 @@
 import os
 from pathlib import Path
+from typing import Dict
+
 import numpy as np
 import datetime
 import shutil
-import json
 import openpyxl
-from openpyxl.cell.cell import Cell
-from openpyxl.styles import Font
-from openpyxl.utils import get_column_letter
+import json
+import ruamel.yaml
 
 from steam_sdk.builders.BuilderLEDET import BuilderLEDET
+from steam_sdk.data.DataLEDET import LEDETInputs, LEDETOptions, LEDETPlots, LEDETVariables
 from steam_sdk.data.TemplateLEDET import get_template_LEDET_inputs_sheet, get_template_LEDET_options_sheet, get_template_LEDET_plots_sheet, get_template_LEDET_variables_sheet
 from steam_sdk.parsers import ParserMap2d
-from steam_sdk.parsers.ParserExcel import read_row, compare_two_parameters, write2Excel
+from steam_sdk.parsers.ParserExcel import read_row, write2Excel
 from steam_sdk.parsers.ParserYAML import dict_to_yaml
 from steam_sdk.utils.NumpyEncoder import NumpyEncoder
+from steam_sdk.utils.rgetattr import rgetattr
+from steam_sdk.utils.sgetattr import rsetattr
+from steam_sdk.utils.compare_two_parameters import compare_two_parameters
 
 
 class ParserLEDET:
@@ -29,6 +33,7 @@ class ParserLEDET:
 
         self.builder_ledet: BuilderLEDET = builder_ledet
 
+
     def readFromExcel(self, file_name: str, verbose: bool = True):
         '''
             *** Function that reads an Excel file defining a LEDET input file and imports it in a BuilderLEDET object ***
@@ -147,7 +152,7 @@ class ParserLEDET:
         :return:
         '''
 
-        self._expandCoolingScalarToArray(verbose)
+        self._expand_scalar_to_array(verbose)
 
         # Import templates for LEDET input file sheets
         template_LEDET_inputs_sheet    = get_template_LEDET_inputs_sheet()
@@ -173,7 +178,7 @@ class ParserLEDET:
             # Get value of the current parameter
             value = self.builder_ledet.getAttribute(name_sheet_inputs, name)
 
-            # Skip optional variables if they have 0 elements
+            # Skip optional variables if they have 0 elements, or if they are all NaN
             if name in optional_variables_input_sheet:
                 if isinstance(value, list) and len(value) == 0:
                     if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
@@ -184,6 +189,9 @@ class ParserLEDET:
                 elif value is None:
                     if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
                     continue
+                elif isinstance(value, np.ndarray) and np.all(np.isnan(value)):
+                    if verbose: print('Variable {} is optional and has only NaN elements, hence it will be skipped.'.format(name))
+                    continue
 
             # Assign value to the variable sheet
             LEDET_inputs_sheet.append([name, value, description])
@@ -254,220 +262,6 @@ class ParserLEDET:
                     verbose=verbose)
 
 
-    def writeLedet2Excel_OLD(self, nameFileLEDET: str, verbose: bool = True, SkipConsistencyCheck: bool = False):
-        '''
-            *** Function that writes a LEDET input file as an Excel file ***
-
-            Function to write a LEDET input file composed of "Inputs", "Options", "Plots", and "Variables" sheets
-
-            :param nameFileLEDET: String defining the name of the LEDET input file to be written
-            :type nameFileLEDET: string
-            :param verbose: flag that determines whether the output are printed
-            :type verbose: bool
-            :param SkipConsistencyCheck: flag that determines, whether the parameters shall be checked for consistency or not [False = Apply checks, True = Skip checks]
-            :type SkipConsistencyCheck: bool
-
-            :return: None
-        '''
-
-        # Unpack variables
-        builder_ledet = self.builder_ledet
-
-        if not SkipConsistencyCheck:
-            if self._consistencyCheckLEDET():
-                print("Variables are not consistent! Writing aborted - ", nameFileLEDET)
-                return
-            else:
-                if verbose: print("Preliminary consistency check was successful! - ", nameFileLEDET)
-        else:
-            print("Skipped consistency checks.")
-
-        workbook = openpyxl.Workbook()
-        workbook.properties.creator = 'STEAM-Team'
-
-        if verbose:
-            print('')
-            print('### Write "Variables" sheet ###')
-        self.writeLedetWorkbookSheet(workbook, "Variables", builder_ledet.Variables, builder_ledet.descriptionsVariables)
-
-        if verbose:
-            print('')
-            print('### Write "Plots" sheet ###')
-        self.writeLedetWorkbookSheet(workbook, "Plots", builder_ledet.Plots, builder_ledet.descriptionsPlots)
-
-        if verbose:
-            print('')
-            print('### Write "Options" sheet ###')
-        self.writeLedetWorkbookSheet(workbook, "Options", builder_ledet.Options, builder_ledet.descriptionsOptions)
-
-        # Special case: if cooling 0 int, expand 0 to all half-turns in the written file. If done, will revert afterwards
-        self._expandCoolingScalarToArray(verbose)
-        if verbose:
-            print('')
-            print('### Write "Inputs" sheet ###')
-        self.writeLedetWorkbookSheet(workbook, "Inputs", builder_ledet.Inputs, builder_ledet.descriptionsInputs)
-
-        # Save the workbook
-        std = workbook['Sheet']
-        workbook.remove(std)
-
-        for s in range(len(workbook.sheetnames)):
-            if workbook.sheetnames[s] == 'Inputs': break
-        workbook.active = s
-        workbook.save(nameFileLEDET)
-
-        # Display time stamp and end run
-        currentDT = datetime.datetime.now()
-        if verbose:
-            print(' ')
-            print('Time stamp: ' + str(currentDT))
-            print('New file ' + nameFileLEDET + ' generated.')
-        return
-
-
-    def writeLedetWorkbookSheet(self, book, sheet, variableGroup, variableLabels, verbose: bool = False):
-        """
-            **Write one sheet of a LEDET input file**
-
-            Function writes one sheet of a LEDET input file
-
-            :param book: workbook object to write
-            :type book: openpyxl.Workbook
-            :param sheet: name of the sheet to write
-            :type sheet: string
-            :param variableGroup: dataclass containing the attributes and values to be written into sheet
-            :type variableGroup: dataclass
-            :param variableLabels: dictionary assigning a description to each variable name
-            :type variableLabels: dict
-            :return:
-        """
-
-        # Unpack variables
-        builder_ledet = self.builder_ledet
-
-        # Define optional variables, which will not be written in the LEDET input file in case their value is not defined (empty list or array)
-        optional_variables = (
-            'alpha_Nb3Sn0_inGroup',
-            'f_scaling_Jc_BSCCO2212_inGroup'
-            )
-
-        # Define cell style
-        def styled_cells(data):
-            for c in data:
-                c = Cell(sheet1, column="A", row=1, value=c)
-                c.font = Font(size=14,bold=True)
-                yield c
-
-        # Loop through sheets to activate the correct sheet to write to
-        book.create_sheet(index = 1 , title = sheet)
-        for s in range(len(book.sheetnames)):
-            if book.sheetnames[s] == sheet: break
-        book.active = s
-        sheet1 = book.active
-
-        # Correct section titles, if Helium option is present
-        if "overwrite_f_externalVoids_inGroup" in variableGroup.__annotations__:
-            ofiVg = builder_ledet.getAttribute(variableGroup, "overwrite_f_externalVoids_inGroup")
-            if len(ofiVg) != 0 and "fitParameters_inGroup" in builder_ledet.sectionTitles.keys():
-                builder_ledet.sectionTitles["overwrite_f_externalVoids_inGroup"] = builder_ledet.sectionTitles["fitParameters_inGroup"]
-                del builder_ledet.sectionTitles["fitParameters_inGroup"]
-
-        # Write to the sheet of the workbook
-        # Loop through all attributes in the given variableGroup
-        for attribute in variableGroup.__annotations__:
-            # Only write the helium options if they are set, otherwise skip
-            if (attribute == "overwrite_f_internalVoids_inGroup"):
-                ofiVg = builder_ledet.getAttribute(variableGroup, attribute)
-                if len(ofiVg) == 0: continue
-            if (attribute == "overwrite_f_externalVoids_inGroup"):
-                ofiVg = builder_ledet.getAttribute(variableGroup, attribute)
-                if len(ofiVg) == 0: continue
-
-            # Skip optional variables if they have 0 elements
-            if attribute in optional_variables:
-                if isinstance(builder_ledet.getAttribute(variableGroup, attribute), list) and len(builder_ledet.getAttribute(variableGroup, attribute)) == 0:
-                    if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(attribute))
-                    continue
-                elif isinstance(builder_ledet.getAttribute(variableGroup, attribute), np.ndarray) and builder_ledet.getAttribute(variableGroup, attribute).shape[0] == 0:
-                    if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(attribute))
-                    continue
-
-            # Skip writing conductor resistance fraction if not enabled
-            lookup = ['f_RRR1_Cu_inGroup', 'f_RRR2_Cu_inGroup', 'f_RRR3_Cu_inGroup',
-                      'RRR1_Cu_inGroup', 'RRR2_Cu_inGroup', 'RRR3_Cu_inGroup']
-            if attribute in lookup and not builder_ledet.enableConductorResistanceFraction:
-                continue
-
-            # Check if size of list is < 16382 (max size of xlsx - 2 rows for descriptions), if so: convert to np.ndarray
-            if isinstance(builder_ledet.getAttribute(variableGroup, attribute), list):
-                if len(builder_ledet.getAttribute(variableGroup, attribute)) > 16382:
-                    builder_ledet.setAttribute(variableGroup, attribute, np.array(builder_ledet.getAttribute(variableGroup, attribute)).reshape(-1, 1))
-            if isinstance(builder_ledet.getAttribute(variableGroup, attribute), np.ndarray):
-                if builder_ledet.getAttribute(variableGroup, attribute).shape[0] > 16382:
-                    builder_ledet.setAttribute(variableGroup, attribute, np.array(builder_ledet.getAttribute(variableGroup, attribute)).reshape(-1, 1))
-
-            # Actual writing process. Check which datatype the attribute is and append it to the sheet
-            # If datatype is matrix, a for loop executes all rows/columns before continuing to next attribute
-            varDesc = variableLabels.get(str(attribute))
-            if isinstance(builder_ledet.getAttribute(variableGroup, attribute), np.ndarray):
-                if builder_ledet.getAttribute(variableGroup, attribute).ndim > 1:
-                    for i in range(builder_ledet.getAttribute(variableGroup, attribute).shape[0]):
-                        values = builder_ledet.getAttribute(variableGroup, attribute)[i,:].tolist()
-                        if i == 0: sheet1.append([varDesc, attribute] + values)
-                        else: sheet1.append([None, None] + values)
-                else:
-                    values = np.array(builder_ledet.getAttribute(variableGroup, attribute)).tolist()
-                    sheet1.append([varDesc, attribute] + values)
-            elif isinstance(builder_ledet.getAttribute(variableGroup, attribute), list):
-                values = builder_ledet.getAttribute(variableGroup, attribute)
-                sheet1.append([varDesc, attribute] + values)
-            else:
-                values = [builder_ledet.getAttribute(variableGroup, attribute)]
-                sheet1.append([varDesc, attribute]+ values)
-
-            if attribute in builder_ledet.sectionTitles.keys():
-                sheet1.append([None])
-                sheet1.append(styled_cells([builder_ledet.sectionTitles[attribute]]))
-
-            # Setting the width of each cells in the workbook [only for good view]
-            width = [80.7109375, 40.7109375, 20.7109375]
-            sheet1.column_dimensions['A'].width = width[0]
-            sheet1.column_dimensions['B'].width = width[1]
-
-            if sheet1.max_column+1 > 18278:
-                smc = 18278
-            else:
-                smc = sheet1.max_column+1
-            for i in range(3,smc):
-                cl = get_column_letter(i)
-                sheet1.column_dimensions[cl].width = width[2]
-
-
-    def _expandCoolingScalarToArray(self, verbose: bool = False):
-        ''' Method adds as many elements as the number of half-turns to selected variables '''
-        # TODO: Method can be made more general
-
-        if isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_down, int) or isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_down, float) or \
-                len(self.builder_ledet.Inputs.sim3D_f_cooling_down) == 1:
-            if verbose: print('sim3D_f_cooling_down is a scalar. Expanding value to all half-turns')
-            self.builder_ledet.Inputs.sim3D_f_cooling_down = np.array([self.builder_ledet.Inputs.sim3D_f_cooling_down] * int(np.sum(self.builder_ledet.Inputs.nT)))
-
-        if isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_up, int) or isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_up, float) or \
-                len(self.builder_ledet.Inputs.sim3D_f_cooling_up) == 1:
-            if verbose: print('sim3D_f_cooling_up is a scalar. Expanding value to all half-turns')
-            self.builder_ledet.Inputs.sim3D_f_cooling_up = np.array([self.builder_ledet.Inputs.sim3D_f_cooling_up] * int(np.sum(self.builder_ledet.Inputs.nT)))
-
-        if isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_left, int) or isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_left, float) or \
-                len(self.builder_ledet.Inputs.sim3D_f_cooling_left) == 1:
-            if verbose: print('sim3D_f_cooling_left is a scalar. Expanding value to all half-turns')
-            self.builder_ledet.Inputs.sim3D_f_cooling_left = np.array([self.builder_ledet.Inputs.sim3D_f_cooling_left] * int(np.sum(self.builder_ledet.Inputs.nT)))
-
-        if isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_right, int) or isinstance(self.builder_ledet.Inputs.sim3D_f_cooling_right, float) or \
-                len(self.builder_ledet.Inputs.sim3D_f_cooling_right) == 1:
-            if verbose: print('sim3D_f_cooling_right is a scalar. Expanding value to all half-turns')
-            self.builder_ledet.Inputs.sim3D_f_cooling_right = np.array([self.builder_ledet.Inputs.sim3D_f_cooling_right] * int(np.sum(self.builder_ledet.Inputs.nT)))
-
-
     def write2json(self, full_path_file_name: str, verbose: bool = True, SkipConsistencyCheck: bool = False):
         '''
             *** Function that writes a LEDET input file as a .json file ***
@@ -508,7 +302,7 @@ class ParserLEDET:
             **builder_ledet.Plots.__dict__,
             **builder_ledet.Variables.__dict__}  # to add program-specific variables
 
-        # Skip optional variables if they have 0 elements
+        # Skip optional variables if they have 0 elements, or if they are all NaN
         for name, value in ledet_data_dict.copy().items():
             if (name in optional_variables_input_sheet) or (name in optional_variables_output_sheet):
                 if isinstance(value, list) and len(value) == 0:
@@ -520,6 +314,9 @@ class ParserLEDET:
                 elif value is None:
                     if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
                     del ledet_data_dict[name]
+                elif isinstance(value, np.ndarray) and np.all(np.isnan(value)):
+                    if verbose: print('Variable {} is optional and has only NaN elements, hence it will be skipped.'.format(name))
+                    del ledet_data_dict[name]
 
         # Write output .json file
         with open(full_path_file_name, 'w') as outfile:
@@ -574,7 +371,7 @@ class ParserLEDET:
             **builder_ledet.Plots.__dict__,
             **builder_ledet.Variables.__dict__}  # to add program-specific variables
 
-        # Skip optional variables if they have 0 elements
+        # Skip optional variables if they have 0 elements, or if they are all NaN
         for name, value in ledet_data_dict.copy().items():
             if (name in optional_variables_input_sheet) or (name in optional_variables_output_sheet):
                 if isinstance(value, list) and len(value) == 0:
@@ -586,6 +383,9 @@ class ParserLEDET:
                 elif value is None:
                     if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
                     del ledet_data_dict[name]
+                elif isinstance(value, np.ndarray) and np.all(np.isnan(value)):
+                    if verbose: print('Variable {} is optional and has only NaN elements, hence it will be skipped.'.format(name))
+                    del ledet_data_dict[name]
 
         # Write output .yaml file
         dict_to_yaml(ledet_data_dict, full_path_file_name, list_exceptions=[])
@@ -599,9 +399,98 @@ class ParserLEDET:
         return
 
 
+    def read_from_json(self, file_name: str, verbose: bool = True):
+        '''
+            *** Function that reads a .json file defining a LEDET input file and imports it in a BuilderLEDET object ***
+
+            :param file_name: Name of the file to read
+            :type file_name: str
+            :param verbose: Flag indicating whether additional information should be displayed
+            :type verbose: str
+
+            :return: None
+        '''
+
+        # Read file as a dictionary
+        with open(file_name) as json_file:
+            dict_data = json.load(json_file)
+
+        # Assign dictionary keys to the four LEDET dataclasses
+        self._assign_dict_to_LEDET_dataclasses(dict_data)
+
+        if verbose:
+            print(f'File {file_name} successfully read.')
+
+
+    def read_from_yaml(self, file_name: str, verbose: bool = True):
+        '''
+            *** Function that reads a .yaml file defining a LEDET input file and imports it in a BuilderLEDET object ***
+
+            :param file_name: Name of the file to read
+            :type file_name: str
+            :param verbose: Flag indicating whether additional information should be displayed
+            :type verbose: str
+
+            :return: None
+        '''
+
+        # Read file as a dictionary
+        yaml = ruamel.yaml.YAML(typ='safe', pure=True)
+        with open(file_name) as yaml_file:
+            dict_data = yaml.load(yaml_file)
+
+        # Assign dictionary keys to the four LEDET dataclasses
+        self._assign_dict_to_LEDET_dataclasses(dict_data)
+
+        if verbose:
+            print(f'File {file_name} successfully read.')
+
+
+    #######################  Helper methods - START  #######################
+    def _expand_scalar_to_array(self, verbose: bool = False):
+        ''' Method adds as many elements as the number of half-turns to selected variables '''
+        # TODO: Method can be made more general
+
+        list_variables_to_expand = [
+            'sim3D_f_cooling_down',
+            'sim3D_f_cooling_up',
+            'sim3D_f_cooling_left',
+            'sim3D_f_cooling_right',
+            ]
+
+        for var_name in list_variables_to_expand:
+            var_value = rgetattr(self.builder_ledet.Inputs, var_name)
+            if isinstance(var_value, (int, float)):
+                if verbose: print(f'{var_name} is a scalar. The same value will be written for all half-turns.')
+            elif isinstance(var_value, (np.ndarray, list)) and len(var_value) == 1:
+                if verbose: print(f'{var_name} is an array or a list of one element. The same value will be written for all half-turns.')
+            else:
+                continue  # do nothing
+            # If the code reaches this line, assign the scalar value to all half-turns
+            rsetattr(self.builder_ledet.Inputs, var_name, np.array([var_value] * int(np.sum(self.builder_ledet.Inputs.nT))))
+
+
+    def _assign_dict_to_LEDET_dataclasses(self, dict_data: Dict):
+        '''
+        Assign the keys of a flat dictionary to the four LEDET dataclasses of a BuilderLEDET object
+        :param dict_data:
+        :return:
+        '''
+        for key, value in dict_data.items():
+            if key in LEDETInputs.__annotations__:
+                self.builder_ledet.setAttribute(self.builder_ledet.Inputs, key, value)
+            if key in LEDETOptions.__annotations__:
+                self.builder_ledet.setAttribute(self.builder_ledet.Options, key, value)
+            if key in LEDETPlots.__annotations__:
+                self.builder_ledet.setAttribute(self.builder_ledet.Plots, key, value)
+            if key in LEDETVariables.__annotations__:
+                self.builder_ledet.setAttribute(self.builder_ledet.Variables, key, value)
+
+    #######################  Helper methods - END  #######################
+
+
 #######################  Methods for consistency checks of LEDET input files - START  #######################
 # TODO: Update consistency checks of LEDET input files to the latest LEDET features
-
     def __getNumberOfCoilSections(self):
         '''
             **Consistency check of LEDET Inputs - Helper function**
@@ -945,6 +834,7 @@ def _getOptionalVariables_input():
         ]
     return optional_variables_input_sheet
 
+
 def _getOptionalVariables_output():
     optional_variables_output_sheet = [
         'fieldMapNumber',
@@ -954,50 +844,62 @@ def _getOptionalVariables_output():
     return optional_variables_output_sheet
 
 
-def CompareLEDETParameters(fileA, fileB, max_relative_error=1E-5, show_indices=0):
+def CompareLEDETParameters(fileA: str, fileB: str, max_relative_error: float=1E-5, verbose=False):
     '''
         Compare all the variables imported from two LEDET Excel input files
+        Returns True if the two files contain LEDET parameters that differ by less than a certain relative error. Returns False otherwise.
     '''
 
-    Diff = 0
-
     pl_a = ParserLEDET(BuilderLEDET(flag_build=False))
     pl_a.readFromExcel(fileA, verbose=False)
     pl_b = ParserLEDET(BuilderLEDET(flag_build=False))
     pl_b.readFromExcel(fileB, verbose=False)
     print("Starting Comparison of A: ({}) and B: ({})".format(fileA, fileB))
 
-    ## Check Inputs
-    for attribute in pl_a.builder_ledet.Inputs.__annotations__:
-        Diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Inputs", attribute),
-                                      pl_b.builder_ledet.getAttribute("Inputs", attribute),
-                                      Diff, attribute, max_relative_error, show_indices)
+    Diff = check_for_differences(pl_a, pl_b, max_relative_error, verbose=verbose)
 
-    ## Check Options
-    for attribute in pl_a.builder_ledet.Options.__annotations__:
-        Diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Options", attribute),
-                                      pl_b.builder_ledet.getAttribute("Options", attribute),
-                                      Diff, attribute, max_relative_error, show_indices)
-
-    ## Check Plots
-    for attribute in pl_a.builder_ledet.Plots.__annotations__:
-        Diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Plots", attribute),
-                                      pl_b.builder_ledet.getAttribute("Plots", attribute),
-                                      Diff, attribute, max_relative_error, show_indices)
-
-    ## Check Variables
-    for attribute in pl_a.builder_ledet.Variables.__annotations__:
-        Diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Variables", attribute),
-                                      pl_b.builder_ledet.getAttribute("Variables", attribute),
-                                      Diff, attribute, max_relative_error, show_indices)
-
-    if Diff == 0:
-        print("Files {} and {} are equal.".format(fileA, fileB))
+    if Diff == False:
+        print(f'Files {fileA} and {fileB} are equal: they contain LEDET parameters that differ by a relative error lower than {max_relative_error}.')
         return True
     else:
         return False
 
 
+def check_for_differences(pl_a, pl_b, max_relative_error, verbose):
+    Diff = False
+
+    ## Check Inputs
+    for attribute in pl_a.builder_ledet.Inputs.__annotations__:
+        last_diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Inputs", attribute),
+                                      pl_b.builder_ledet.getAttribute("Inputs", attribute),
+                                      attribute, max_relative_error, flag_difference_messages=True, verbose=verbose)
+        if last_diff: Diff = True
+
+    ## Check Options
+    for attribute in pl_a.builder_ledet.Options.__annotations__:
+        last_diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Options", attribute),
+                                      pl_b.builder_ledet.getAttribute("Options", attribute),
+                                      attribute, max_relative_error, flag_difference_messages=True, verbose=verbose)
+        if last_diff: Diff = True
+
+    ## Check Plots
+    for attribute in pl_a.builder_ledet.Plots.__annotations__:
+        last_diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Plots", attribute),
+                                      pl_b.builder_ledet.getAttribute("Plots", attribute),
+                                      attribute, max_relative_error, flag_difference_messages=True, verbose=verbose)
+        if last_diff: Diff = True
+
+    ## Check Variables
+    for attribute in pl_a.builder_ledet.Variables.__annotations__:
+        last_diff = compare_two_parameters(pl_a.builder_ledet.getAttribute("Variables", attribute),
+                                      pl_b.builder_ledet.getAttribute("Variables", attribute),
+                                      attribute, max_relative_error, flag_difference_messages=True, verbose=verbose)
+        if last_diff: Diff = True
+
+    return Diff
+
+
+
 def copy_map2d(magnet_name: str, map2d_file_name: str, output_path: str, flagIron: int, flagSelfField: int,
                suffix: str = '', verbose: bool = False):
     ''' rename and copy '''
