@@ -1,17 +1,17 @@
 import os
+import csv
 import datetime
 import ntpath
 import shutil
 import textwrap
+from itertools import zip_longest
 from pathlib import Path
-from typing import Union
-
+from typing import Union, List
 import matplotlib.pyplot as plt
 from scipy.interpolate import UnivariateSpline
 from scipy.interpolate import interp1d
 import pandas as pd
 import numpy as np
-
 import yaml
 
 from steam_sdk.data.DataModelCircuit import DataModelCircuit, Component
@@ -869,7 +869,7 @@ def InterpolateResistance(current_level: float, path_resources: str, n_apertures
 
     for col in Intp_data.columns:
         try:
-            _ = int(col)
+            _ = float(col)
             idx = Intp_data.columns.get_loc(col)
             col_t.append(Intp_data.columns[idx]) # Time
             col_r1.append(Intp_data.columns[idx + 1]) # Aperture 1
@@ -1113,33 +1113,39 @@ def writeStimuliFromInterpolation_general(current_level: list, n_total_magnets:
     # Ensure consistency of inputs
     if len(magnets) != len(tShift): raise Exception(f'Please provide a time shift for each magnet. '
                                                     f'Size of magnet list is {len(magnets)}, but size of tShift is {len(tShift)}')
-    if len(magnet_type) != len(magnets): raise Exception(f'Please provide a magnet type for interpolation of each magnet.'
+    if len(magnet_type) != n_total_magnets: raise Exception(f'Please provide a magnet type for interpolation of each magnet.'
                                                          f'Size of magnet_type is {len(magnet_type)}, but size of magnet list is {len(magnets)}')
     R1 = np.array([])
     R2 = np.array([])
     print("Interpolating Coil-Resistances")
     stlString = ''
     # Interpolate data for each current level and ensure correct data format
+    current_count=0
     for k in range(1, n_total_magnets + 1):
-        for l in current_level:
-            if n_apertures == 2:
-                [time, data_R1, data_R2] = InterpolateResistance(l, path_resources[k-1], n_apertures=n_apertures, Type = InterpolationType)
-            else:
-                [time, data_R1] = InterpolateResistance(l, path_resources[k-1], n_apertures=n_apertures, Type=InterpolationType)
-            if not R1.size > 0:
-                R1 = data_R1[np.newaxis, ...]
-            else:
-                R1 = np.vstack((R1, data_R1))
-            if n_apertures == 2:
-                if not R2.size > 0:
-                    R2 = data_R2[np.newaxis, ...]
+        if k in magnets:
+            current_level_mag = current_level[current_count]
+            current_count=current_count+1
+            if type(current_level_mag) != list:
+                current_level_mag = [current_level_mag]
+            for g in current_level_mag:
+                if n_apertures == 2:
+                    [time, data_R1, data_R2] = InterpolateResistance(g, path_resources[magnet_type[k-1]-1], n_apertures=n_apertures, Type = InterpolationType)
                 else:
-                    R2 = np.vstack((R2, data_R2))
+                    [time, data_R1] = InterpolateResistance(g, path_resources[magnet_type[k-1]-1], n_apertures=n_apertures, Type=InterpolationType)
+                if not R1.size > 0:
+                    R1 = data_R1[np.newaxis, ...]
+                else:
+                    R1 = np.vstack((R1, data_R1))
+                if n_apertures == 2:
+                    if not R2.size > 0:
+                        R2 = data_R2[np.newaxis, ...]
+                    else:
+                        R2 = np.vstack((R2, data_R2))
         #stlString = ''
 
     # Loop through all current level
     #for k in range(1, n_total_magnets+1):
-        if k in magnets:
+        #if k in magnets:
             index = magnets.index(k)
             timeShift = tShift[index]
             if timeShift < 0: timeShift = 0
@@ -1153,7 +1159,7 @@ def writeStimuliFromInterpolation_general(current_level: list, n_total_magnets:
             for l in range(1, R1.shape[1] - 1):
                 if np.isnan(R1[index, l]): continue
                 # Ensure starting at 0 (No negative time in PSPICE allowed
-                if float(time[l]) < 0:  timeShift = timeShift + abs(float(time[l])) - 0.03
+                if float(time[l]) < 0:  timeShift = timeShift + abs(float(time[l]))
                 if float(time[l]) + timeShift < 0:
                     tt = 0
                 else:
@@ -1166,6 +1172,7 @@ def writeStimuliFromInterpolation_general(current_level: list, n_total_magnets:
             # Write last time value to be 10000 s, with last resistance (resistance is assumed to stay constant)
             R1_last = R1[index]
             R1_last = R1_last[~np.isnan(R1_last)]
+            R1_last = R1_last[~np.isnan(R1_last)]
             stlString = stlString + "+ ( " + str(10000) + "s," + str(R1_last[-1]) + " ) \n"
             stlString = stlString + " \n"
 
@@ -1175,15 +1182,15 @@ def writeStimuliFromInterpolation_general(current_level: list, n_total_magnets:
                                         f'PWL \n+ TIME_SCALE_FACTOR = 1 \n+ VALUE_SCALE_FACTOR = 1 \n'
                 stlString = stlString + "+ ( 0s, 0.0 )\n"
                 count = 0
-                for l in range(1, R2.shape[1] - 1):
-                    if np.isnan(R2[index, l]): continue
-                    if float(time[l]) < 0:  timeShift = timeShift + abs(float(time[l])) - 0.03
-                    if float(time[l]) + timeShift < 0:
+                for h in range(1, R2.shape[1] - 1):
+                    if np.isnan(R2[index, h]): continue
+                    if float(time[h]) < 0:  timeShift = timeShift + abs(float(time[h]))
+                    if float(time[h]) + timeShift < 0:
                         tt = 0
                     else:
-                        tt = float(time[l]) + timeShift
+                        tt = float(time[h]) + timeShift
                     if count >= sparseTimeStepping:
-                        stlString = stlString + "+ ( " + str(tt) + "s, " + str(R2[index, l]) + " )\n"
+                        stlString = stlString + "+ ( " + str(tt) + "s, " + str(R2[index, h]) + " )\n"
                         count = 0
                     count = count + 1
                 R2_last = R2[index]
@@ -1205,3 +1212,29 @@ def writeStimuliFromInterpolation_general(current_level: list, n_total_magnets:
     # Write the stimuli as a txt(stl) file
     with open(Outputfile, type_stl) as ofile:
         ofile.write(stlString)
+
+
+def write_coil_resistance_interpolation_file(path_csv_file: str, current_levels: List[float], list_times: List, list_coil_resistances: List, format: str = '{:3.10e}'):
+    '''
+    This function writes a coil resistance interpolation file with a format compatible with the function ParserPSPICE.writeStimuliFromInterpolation_general()
+
+    :param path_csv_file: path to the output .csv file to write
+    :param current_levels: list with defined current levels
+    :param list_times: list of lists, where each list defines the time vector at one current level 
+    :param list_coil_resistances: list of lists, where each list defines the time vector at one current level
+    :param format: string defining the format for the written variables
+    :return: 
+    '''
+
+    columns_to_write = []
+    for c, current in enumerate(current_levels):
+        time_to_write = [format.format(t) for t in list_times[c]]
+        R_to_write = [format.format(t) for t in list_coil_resistances[c]]
+        columns_to_write.append([current, "time_vector"] + time_to_write)  # TODO remove the call to int() once the interpolation function can deal with it
+        columns_to_write.append(["", "R_CoilSections_1"] + R_to_write)
+        columns_to_write.append(["", ""] + len(list_times[c]) * [None])
+    rows_to_write = zip_longest(*columns_to_write, fillvalue='')
+
+    with open(path_csv_file, 'w', newline='') as file:
+        wr = csv.writer(file)
+        wr.writerows(rows_to_write)
\ No newline at end of file
