@@ -3,7 +3,8 @@ import openpyxl
 
 from steam_sdk.builders.BuilderProteCCT import BuilderProteCCT
 from steam_sdk.data.TemplateProteCCT import get_template_ProteCCT_input_sheet
-from steam_sdk.parsers.ParserExcel import read_row, write2Excel, compare_two_parameters
+from steam_sdk.parsers.ParserExcel import read_row, write2Excel
+from steam_sdk.utils.compare_two_parameters import compare_two_parameters
 
 
 class ParserProteCCT:
@@ -119,12 +120,12 @@ class ParserProteCCT:
 
 
 #######################  Helper functions - START  #######################
-def CompareProteCCTParameters(fileA, fileB, max_relative_error=1E-5, show_indices=0):
+def CompareProteCCTParameters(fileA, fileB, max_relative_error=1E-5, verbose=True):
     """
         Compare all the variables imported from two ProteCCT Excel input files
     """
 
-    Diff = 0
+    Diff = False
 
     pp_a = ParserProteCCT(BuilderProteCCT(flag_build=False))
     pp_a.readFromExcel(fileA, verbose=False)
@@ -134,11 +135,13 @@ def CompareProteCCTParameters(fileA, fileB, max_relative_error=1E-5, show_indice
 
     ## Check Inputs
     for attribute in pp_a.builder_protecct.Inputs.__annotations__:
-        Diff = compare_two_parameters(pp_a.builder_protecct.getAttribute("Inputs", attribute),
+        last_diff = compare_two_parameters(pp_a.builder_protecct.getAttribute("Inputs", attribute),
                                       pp_b.builder_protecct.getAttribute("Inputs", attribute),
-                                      Diff, attribute, max_relative_error, show_indices)
+                                      attribute, max_relative_error, flag_difference_messages=True, verbose=verbose)
+        if last_diff:
+            Diff = True
 
-    if Diff == 0:
+    if Diff == False:
         print("Files {} and {} are equal.".format(fileA, fileB))
         return True
     else:
