@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from steam_sdk.parsers.ParserYAML import yaml_to_data_class, dict_to_yaml
+from steam_sdk.parsers.ParserYAML import yaml_to_data, dict_to_yaml
 
 from steam_sdk.builders.BuilderPyBBQ import BuilderPyBBQ
 from steam_sdk.data.DataPyBBQ import DataPyBBQ
@@ -25,7 +25,7 @@ class ParserPyBBQ:
         # TODO documentation
 
         # Load yaml keys into DataModelMagnet dataclass
-        self.builder_PyBBQ.data_PyBBQ = yaml_to_data_class(file_name, DataPyBBQ)
+        self.builder_PyBBQ.data_PyBBQ = yaml_to_data(file_name, DataPyBBQ)
         if verbose: print('File {} was loaded.'.format(file_name))
 
 
