@@ -14,30 +14,30 @@ from steam_sdk.data import DataRoxieParser as pd
 # import matplotlib.patches as patches
 
 
-def arcCenter(C, iL, oL, iR, oR, diff_radius=None):
-    inner_radius = (np.sqrt(np.square(iL.x - C.x) + np.square(iL.y - C.y)) +
-                    np.sqrt(np.square(iR.x - C.x) + np.square(iR.y - C.y))) / 2
+def arcCenter(C, iH, oH, iLA, oLA, diff_radius=None):
+    inner_radius = (np.sqrt(np.square(iH.x - C.x) + np.square(iH.y - C.y)) +
+                    np.sqrt(np.square(iLA.x - C.x) + np.square(iLA.y - C.y))) / 2
     if diff_radius:
         outer_radius = inner_radius + diff_radius
     else:
-        outer_radius = (np.sqrt(np.square(oL.x - C.x) + np.square(oL.y - C.y)) +
-                        np.sqrt(np.square(oR.x - C.x) + np.square(oR.y - C.y))) / 2
-    d_inner = [0.5 * abs((iR.x - iL.x)), 0.5 * abs((iL.y - iR.y))]
-    d_outer = [0.5 * abs((oR.x - oL.x)), 0.5 * abs((oL.y - oR.y))]
+        outer_radius = (np.sqrt(np.square(oH.x - C.x) + np.square(oH.y - C.y)) +
+                        np.sqrt(np.square(oLA.x - C.x) + np.square(oLA.y - C.y))) / 2
+    d_inner = [0.5 * abs((iLA.x - iH.x)), 0.5 * abs((iH.y - iLA.y))]
+    d_outer = [0.5 * abs((oLA.x - oH.x)), 0.5 * abs((oH.y - oLA.y))]
     aa = [np.sqrt(np.square(d_inner[0]) + np.square(d_inner[1])),
           np.sqrt(np.square(d_outer[0]) + np.square(d_outer[1]))]
     bb = [np.sqrt(np.square(inner_radius) - np.square(aa[0])), np.sqrt(np.square(outer_radius) - np.square(aa[1]))]
-    if iR.y < iL.y:
-        M_inner = [iL.x + d_inner[0], iR.y + d_inner[1]]
-        M_outer = [oL.x + d_outer[0], oR.y + d_outer[1]]
-        if iR.y >= 0.:
+    if iLA.y < iH.y:
+        M_inner = [iH.x + d_inner[0], iLA.y + d_inner[1]]
+        M_outer = [oH.x + d_outer[0], oLA.y + d_outer[1]]
+        if iLA.y >= 0.:
             sign = [-1, -1]
         else:
             sign = [1, 1]
     else:
-        M_inner = [iL.x + d_inner[0], iL.y + d_inner[1]]
-        M_outer = [oL.x + d_outer[0], oL.y + d_outer[1]]
-        if iR.y >= 0.:
+        M_inner = [iH.x + d_inner[0], iH.y + d_inner[1]]
+        M_outer = [oH.x + d_outer[0], oH.y + d_outer[1]]
+        if iLA.y >= 0.:
             sign = [1, -1]
         else:
             sign = [-1, 1]
@@ -84,17 +84,17 @@ class RoxieList:
         self.i_strand = []
         self.strand_to_halfTurn = []
         self.idx_half_turn = 0
-        for eo in roxie_data.coil.electrical_order:
+        for eo in roxie_data.coil.physical_order:
             winding = roxie_data.coil.coils[eo.coil].poles[eo.pole].layers[eo.layer].windings[eo.winding]
             block = winding.blocks[eo.block]
             for halfTurn_nr, halfTurn in block.half_turns.items():
                 self.idx_half_turn = self.idx_half_turn + 1
                 insulated = halfTurn.corners.insulated
                 bare = halfTurn.corners.bare
-                self.x_insulated.append([insulated.iL.x, insulated.oL.x, insulated.oR.x, insulated.iR.x])
-                self.y_insulated.append([insulated.iL.y, insulated.oL.y, insulated.oR.y, insulated.iR.y])
-                self.x_bare.append([bare.iL.x, bare.oL.x, bare.oR.x, bare.iR.x])
-                self.y_bare.append([bare.iL.y, bare.oL.y, bare.oR.y, bare.iR.y])
+                self.x_insulated.append([insulated.iH.x, insulated.oH.x, insulated.oLA.x, insulated.iLA.x])
+                self.y_insulated.append([insulated.iH.y, insulated.oH.y, insulated.oLA.y, insulated.iLA.y])
+                self.x_bare.append([bare.iH.x, bare.oH.x, bare.oLA.x, bare.iLA.x])
+                self.y_bare.append([bare.iH.y, bare.oH.y, bare.oLA.y, bare.iLA.y])
                 self.i_conductor.append(block.current_sign)
 
                 for strand_gr_nr, strand_gr in halfTurn.strand_groups.items():
@@ -118,6 +118,7 @@ class ParserRoxie:
     dir_data: Path = None
     dir_cadata: Path = None
 
+    cond_tot: int = 0
     no: int = None
     shift_flag: int = 0
     block: pd.Block = pd.Block()
@@ -1124,9 +1125,8 @@ class ParserRoxie:
             self.data = pd.RoxieData()
             self.cond_parameters = conductor
             self.no = 1
+            self.cond_tot = 0
 
-        x0 = 0
-        y0 = 0
         radius = self.block.radius / 1000  # in [m]
         phi = self.block.phi / 180 * math.pi  # in [rad]
         alpha = self.block.alpha / 180 * math.pi  # in [rad]
@@ -1155,7 +1155,7 @@ class ParserRoxie:
 
         # Define the coefficients of the circle on which the x2 points (bottom-left) of each conductor rest
         # R, x0, and y0 coefficients of the circle, as in: (x-x0)**2 + (y-y0)**2 = R**2
-        circle = [radius, x0, y0]
+        circle = [radius, 0, 0]
 
         # Define x/y positions, including conductor rotation of angle=alpha around origin (x0Cond,y0Cond)
         alphaTemp = alpha
@@ -1187,8 +1187,9 @@ class ParserRoxie:
         winding.blocks[self.no] = pd.BlockData(block_corners=pd.Corner(), current_sign=int(np.sign(self.block.current)))
         block = winding.blocks[self.no]
 
-        for c in range(self.block.nco):
-            block.half_turns[c + 1] = pd.HalfTurn(corners=pd.HalfTurnCorner())
+        for c in range(1, self.block.nco + 1):
+            ht_nr = c + self.cond_tot
+            block.half_turns[ht_nr] = pd.HalfTurn(corners=pd.HalfTurnCorner())
 
             # Calculate coordinates of four corner of bare and insulated conductor
             if self.block.type == 1:  # cos-theta
@@ -1246,7 +1247,7 @@ class ParserRoxie:
                         print('The closest point was selected: [{},{}].'.format(next_x2, next_y2))
 
                 # Find new phi angle: the angle between the X-axis and the line joining [next_x2,next_y2] and [x0,y0]
-                phi = math.atan2(next_y2 - y0, next_x2 - x0)
+                phi = math.atan2(next_y2, next_x2)
 
                 if verbose:
                     print('phi = {} rad'.format(phi))
@@ -1265,7 +1266,7 @@ class ParserRoxie:
 
                 # Update xTemp and yTemp (using insulated conductor positions)
                 # xTemp = xTemp
-                yTemp = yTemp + (hInBare + 2 * wInsulWide)
+                yTemp += hInBare + 2 * wInsulWide
 
             else:
                 raise Exception('Block {} is of unknown type: {}. Not supported'.format(self.no, self.block.type))
@@ -1273,9 +1274,8 @@ class ParserRoxie:
             if self.block.type == 2:  # block-coil
                 # Apply conductor rotation of angle=alpha around origin (x0Cond,y0Cond)
                 for i, arg in enumerate(xBareCable):
-                    (xBareCable[i], yBareCable[i]) = gf.rotatePoint((xBareCable[i], yBareCable[i]),
-                                                                    (radius, y0Cond), alpha)
-                    (xCable[i], yCable[i]) = gf.rotatePoint((xCable[i], yCable[i]), (radius, y0Cond), alpha)
+                    xBareCable[i], yBareCable[i] = gf.rotatePoint((xBareCable[i], yBareCable[i]), (radius, y0Cond), alpha)
+                    xCable[i], yCable[i] = gf.rotatePoint((xCable[i], yCable[i]), (radius, y0Cond), alpha)
 
             # Mirror conductor about the X-axis
             if self.block.imag == 1:
@@ -1288,56 +1288,59 @@ class ParserRoxie:
                                 .format(self.block.imag))
 
             for i, arg in enumerate(xBareCable):
-                # Apply conductor rotation of angle=turn around origin (x0,y0)
-                (xBareCable[i], yBareCable[i]) = gf.rotatePoint((xBareCable[i], yBareCable[i]), (x0, y0), turn)
-                (xCable[i], yCable[i]) = gf.rotatePoint((xCable[i], yCable[i]), (x0, y0), turn)
+                # Apply conductor rotation of angle=turn around the origin
+                xBareCable[i], yBareCable[i] = gf.rotatePoint((xBareCable[i], yBareCable[i]), (0, 0), turn)
+                xCable[i], yCable[i] = gf.rotatePoint((xCable[i], yCable[i]), (0, 0), turn)
 
                 # Apply roll2 counterclockwise rotation transformation
-                (xBareCable[i], yBareCable[i]) = gf.rotatePoint((xBareCable[i], yBareCable[i]),
-                                                                (x0Roll, y0Roll), alphaRoll)
-                (xCable[i], yCable[i]) = gf.rotatePoint((xCable[i], yCable[i]), (x0Roll, y0Roll), alphaRoll)
+                xBareCable[i], yBareCable[i] = gf.rotatePoint((xBareCable[i], yBareCable[i]), (x0Roll, y0Roll), alphaRoll)
+                xCable[i], yCable[i] = gf.rotatePoint((xCable[i], yCable[i]), (x0Roll, y0Roll), alphaRoll)
 
                 # Apply shift2 cartesian shift transformation
                 xBareCable[i], yBareCable[i] = xBareCable[i] + shiftX, yBareCable[i] + shiftY
                 xCable[i], yCable[i] = xCable[i] + shiftX, yCable[i] + shiftY
 
             # Store cable positions
-            block.half_turns[c + 1].corners.insulated = pd.Corner(iL=pd.Coord(x=sigDig(xCable[0]), y=sigDig(yCable[0])),
-                                                                  iR=pd.Coord(x=sigDig(xCable[1]), y=sigDig(yCable[1])),
-                                                                  oR=pd.Coord(x=sigDig(xCable[2]), y=sigDig(yCable[2])),
-                                                                  oL=pd.Coord(x=sigDig(xCable[3]), y=sigDig(yCable[3])))
-            block.half_turns[c + 1].corners.bare = pd.Corner(
-                iL=pd.Coord(x=sigDig(xBareCable[0]), y=sigDig(yBareCable[0])),
-                iR=pd.Coord(x=sigDig(xBareCable[1]), y=sigDig(yBareCable[1])),
-                oR=pd.Coord(x=sigDig(xBareCable[2]), y=sigDig(yBareCable[2])),
-                oL=pd.Coord(x=sigDig(xBareCable[3]), y=sigDig(yBareCable[3])))
+            block.half_turns[ht_nr].corners.insulated = pd.Corner(iH=pd.Coord(x=sigDig(xCable[0 if self.block.imag == 0 else 1]),
+                                                                              y=sigDig(yCable[0 if self.block.imag == 0 else 1])),
+                                                                  iLA=pd.Coord(x=sigDig(xCable[1 if self.block.imag == 0 else 0]),
+                                                                               y=sigDig(yCable[1 if self.block.imag == 0 else 0])),
+                                                                  oLA=pd.Coord(x=sigDig(xCable[2 if self.block.imag == 0 else 3]),
+                                                                               y=sigDig(yCable[2 if self.block.imag == 0 else 3])),
+                                                                  oH=pd.Coord(x=sigDig(xCable[3 if self.block.imag == 0 else 2]),
+                                                                              y=sigDig(yCable[3 if self.block.imag == 0 else 2])))
+            block.half_turns[ht_nr].corners.bare = pd.Corner(
+                iH=pd.Coord(x=sigDig(xBareCable[0 if self.block.imag == 0 else 1]), y=sigDig(yBareCable[0 if self.block.imag == 0 else 1])),
+                iLA=pd.Coord(x=sigDig(xBareCable[1 if self.block.imag == 0 else 0]), y=sigDig(yBareCable[1 if self.block.imag == 0 else 0])),
+                oLA=pd.Coord(x=sigDig(xBareCable[2 if self.block.imag == 0 else 3]), y=sigDig(yBareCable[2 if self.block.imag == 0 else 3])),
+                oH=pd.Coord(x=sigDig(xBareCable[3 if self.block.imag == 0 else 2]), y=sigDig(yBareCable[3 if self.block.imag == 0 else 2])))
 
             # if c == self.block.nco - 1:
-            #     block.block_corners.iL = pd.Coord(x=sigDig(xCable[0]), y=sigDig(yCable[0]))  # 1
-            #     block.block_corners.oL = pd.Coord(x=sigDig(xCable[3]), y=sigDig(yCable[3]))  # 4
+            #     block.block_corners.iH = pd.Coord(x=sigDig(xCable[0]), y=sigDig(yCable[0]))  # 1
+            #     block.block_corners.oH = pd.Coord(x=sigDig(xCable[3]), y=sigDig(yCable[3]))  # 4
             # elif c == 0:
-            #     block.block_corners.iR = pd.Coord(x=sigDig(xCable[1]), y=sigDig(yCable[1]))  # 2
-            #     block.block_corners.oR = pd.Coord(x=sigDig(xCable[2]), y=sigDig(yCable[2]))  # 3
+            #     block.block_corners.iLA = pd.Coord(x=sigDig(xCable[1]), y=sigDig(yCable[1]))  # 2
+            #     block.block_corners.oLA = pd.Coord(x=sigDig(xCable[2]), y=sigDig(yCable[2]))  # 3
             # else:
             #     pass
 
-            if c == self.block.nco - 1 and c == 0:
+            if c == self.block.nco and c == 1:
                 corner0 = [xCable[0], yCable[0]]  # 1
                 corner3 = [xCable[3], yCable[3]]  # 4
                 corner1 = [xCable[1], yCable[1]]  # 2
                 corner2 = [xCable[2], yCable[2]]  # 3
-            elif c == self.block.nco - 1 and c == 1:
+            elif c == self.block.nco and c == 2:
                 corner0 = [xCable[0], yCable[0]]  # 1
                 corner3 = [xCable[3], yCable[3]]  # 4
                 corner_aux_i_next = [xCable[1], yCable[1]]
                 corner_aux_o_next = [xCable[2], yCable[2]]
-            elif c == self.block.nco - 1:
+            elif c == self.block.nco:
                 corner0 = [xCable[0], yCable[0]]  # 1
                 corner3 = [xCable[3], yCable[3]]  # 4
+            elif c == 2:
+                corner_aux_i_next = [xCable[1], yCable[1]]
+                corner_aux_o_next = [xCable[2], yCable[2]]
             elif c == 1:
-                corner_aux_i_next = [xCable[1], yCable[1]]
-                corner_aux_o_next = [xCable[2], yCable[2]]
-            elif c == 0:
                 corner1 = [xCable[1], yCable[1]]  # 2
                 corner2 = [xCable[2], yCable[2]]  # 3
                 corner_aux_i = [xCable[0], yCable[0]]
@@ -1355,7 +1358,7 @@ class ParserRoxie:
             sinAlphaS = math.sin(alphaS)
             cosAlphaS = math.cos(alphaS)
             for j in range(nLayers):
-                block.half_turns[c + 1].strand_groups[j + 1] = pd.StrandGroup()
+                block.half_turns[ht_nr].strand_groups[j + 1] = pd.StrandGroup()
 
                 for k in range(nColumns):
                     arg = [wBare / nColumns * (k + 1 / 2),
@@ -1371,12 +1374,12 @@ class ParserRoxie:
                                         .format(self.block.imag))
 
                     # Store strand position
-                    block.half_turns[c + 1].strand_groups[j + 1].strand_positions[k + 1] = pd.Coord(x=sigDig(xStrand),
-                                                                                                    y=sigDig(yStrand))
-
+                    block.half_turns[ht_nr].strand_groups[j + 1].strand_positions[k + 1] =\
+                        pd.Coord(x=sigDig(xStrand), y=sigDig(yStrand))
                     # xS.append(xStrand)
                     # yS.append(yStrand)
                     # # iS.append(currentStrand)
+        self.cond_tot += self.block.nco
 
         # Compute two new corners to make concentric blocks by intersecting a circle (having a radius equal to the
         # distance between the bore center and the starting inner/outer block corner) with the straight line
@@ -1388,10 +1391,10 @@ class ParserRoxie:
         # self.ax.add_line(lines.Line2D([corner1[0], corner0[0]], [corner1[1], corner0[1]], color='red'))
         # plt.show()
         if self.block.type == 2 or self.block.nco == 1:
-            block.block_corners.iL = pd.Coord(x=sigDig(corner0[0]), y=sigDig(corner0[1]))  # 1
-            block.block_corners.oL = pd.Coord(x=sigDig(corner3[0]), y=sigDig(corner3[1]))  # 4
-            block.block_corners.iR = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
-            block.block_corners.oR = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
+            block.block_corners.iH = pd.Coord(x=sigDig(corner0[0]), y=sigDig(corner0[1]))  # 1
+            block.block_corners.oH = pd.Coord(x=sigDig(corner3[0]), y=sigDig(corner3[1]))  # 4
+            block.block_corners.iLA = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
+            block.block_corners.oLA = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
         else:
             new_corners_inner = gf.intersectLineCircle(gf.findLineThroughTwoPoints(corner0, corner3),
                                                        [radius, coil.bore_center.x, coil.bore_center.y])
@@ -1445,16 +1448,17 @@ class ParserRoxie:
             # else:
             #     mid_outer_beg = new_corners_outer_mid[1]
 
-            if corner0[0] < corner1[0]:
-                block.block_corners.iL = pd.Coord(x=sigDig(mid_inner_end[0]), y=sigDig(mid_inner_end[1]))  # 1
-                block.block_corners.oL = pd.Coord(x=sigDig(mid_outer_end[0]), y=sigDig(mid_outer_end[1]))  # 4
-                block.block_corners.iR = pd.Coord(x=sigDig(mid_inner_beg[0]), y=sigDig(mid_inner_beg[1]))  # 2
-                block.block_corners.oR = pd.Coord(x=sigDig(mid_outer_beg[0]), y=sigDig(mid_outer_beg[1]))  # 3
+            if self.block.imag == 0:
+                block.block_corners.iH = pd.Coord(x=sigDig(mid_inner_end[0]), y=sigDig(mid_inner_end[1]))  # 1
+                block.block_corners.oH = pd.Coord(x=sigDig(mid_outer_end[0]), y=sigDig(mid_outer_end[1]))  # 4
+                block.block_corners.iLA = pd.Coord(x=sigDig(mid_inner_beg[0]), y=sigDig(mid_inner_beg[1]))  # 2
+                block.block_corners.oLA = pd.Coord(x=sigDig(mid_outer_beg[0]), y=sigDig(mid_outer_beg[1]))  # 3
             else:
-                block.block_corners.iR = pd.Coord(x=sigDig(mid_inner_end[0]), y=sigDig(mid_inner_end[1]))
-                block.block_corners.oR = pd.Coord(x=sigDig(mid_outer_end[0]), y=sigDig(mid_outer_end[1]))
-                block.block_corners.iL = pd.Coord(x=sigDig(mid_inner_beg[0]), y=sigDig(mid_inner_beg[1]))
-                block.block_corners.oL = pd.Coord(x=sigDig(mid_outer_beg[0]), y=sigDig(mid_outer_beg[1]))
+                block.block_corners.iLA = pd.Coord(x=sigDig(mid_inner_end[0]), y=sigDig(mid_inner_end[1]))
+                block.block_corners.oLA = pd.Coord(x=sigDig(mid_outer_end[0]), y=sigDig(mid_outer_end[1]))
+                block.block_corners.iH = pd.Coord(x=sigDig(mid_inner_beg[0]), y=sigDig(mid_inner_beg[1]))
+                block.block_corners.oH = pd.Coord(x=sigDig(mid_outer_beg[0]), y=sigDig(mid_outer_beg[1]))
+
             # new_corners_inner = gf.intersectLineCircle(
             #     gf.findLineThroughTwoPoints(corner0, corner3),
             #     [radius, coil.bore_center.x, coil.bore_center.y])
@@ -1474,20 +1478,20 @@ class ParserRoxie:
             # else:
             #     new_outer = new_corners_outer[1]
             # if corner0[0] < corner1[0]:
-            #     block.block_corners.iL = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))  # 1
-            #     block.block_corners.oL = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))  # 4
-            #     block.block_corners.iR = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
-            #     block.block_corners.oR = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
+            #     block.block_corners.iH = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))  # 1
+            #     block.block_corners.oH = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))  # 4
+            #     block.block_corners.iLA = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
+            #     block.block_corners.oLA = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
             # else:
-            #     block.block_corners.iR = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))
-            #     block.block_corners.oR = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))
-            #     block.block_corners.iL = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))
-            #     block.block_corners.oL = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))
+            #     block.block_corners.iLA = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))
+            #     block.block_corners.oLA = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))
+            #     block.block_corners.iH = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))
+            #     block.block_corners.oH = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))
 
         # ((block.pole % 2 == 0) * np.sign(-I[0]) +
         #  (block.pole % 2 != 0) * np.sign(I[0])) * block.radius / 1e3]
 
-        return self.data.coil.coils if block else self.data.coil
+        return self.data.coil
 
     def getCablePositions(self, blocks: Dict[str, pd.Block] = None, cadata: pd.Cadata = None, verbose: bool = False):
         """
@@ -1516,7 +1520,7 @@ class ParserRoxie:
         for no in self.roxieData.coil.blocks:
             self.no = int(no)
             self.block = self.roxieData.coil.blocks[no]
-            self.data.coil.electrical_order.append(
+            self.data.coil.physical_order.append(
                 pd.Order(coil=self.block.coil, pole=self.block.pole, layer=self.block.layer, winding=self.block.winding,
                          block=self.no))
 
@@ -1549,8 +1553,11 @@ class ParserRoxie:
             :return: list
         """
         if coil:
+            self.data = pd.RoxieData()
             self.data.coil = coil
 
+        # ax = plt.axes()
+
         wedge_no = 0
         for coil_nr, coil in self.data.coil.coils.items():
             for pole_nr, pole in coil.poles.items():
@@ -1568,28 +1575,44 @@ class ParserRoxie:
                                 wedge.coil = coil_nr
 
                                 if blocks.index(block_key) == 0:
-                                    corners1 = block.block_corners
-                                    corners2 = adj_winding.blocks[adj_blocks[0]].block_corners
+                                    wedge.corners = pd.Corner(iH=adj_winding.blocks[adj_blocks[0]].block_corners.iLA, iLA=block.block_corners.iH,
+                                                              oH=adj_winding.blocks[adj_blocks[0]].block_corners.oLA, oLA=block.block_corners.oH)
                                 else:
-                                    corners2 = block.block_corners
-                                    corners1 = adj_winding.blocks[adj_blocks[blocks.index(block_key)]].block_corners
-
-                                if corners1.iR.y >= 0.:
-                                    wedge.corners = pd.Corner(iL=corners2.iR, iR=corners1.iL,
-                                                              oL=corners2.oR, oR=corners1.oL)
-                                else:
-                                    wedge.corners = pd.Corner(iL=corners1.iR, iR=corners2.iL,
-                                                              oL=corners1.oR, oR=corners2.oL)
+                                    wedge.corners = pd.Corner(iH=block.block_corners.iLA, iLA=adj_winding.blocks[adj_blocks[blocks.index(block_key)]].block_corners.iH,
+                                                              oH=block.block_corners.oLA, oLA=adj_winding.blocks[adj_blocks[blocks.index(block_key)]].block_corners.oH)
+                                # ax.text(wedge.corners.iH.x, wedge.corners.iH.y, 'iH', style='italic', bbox={'facecolor': 'red', 'pad': 2})
+                                # ax.text(wedge.corners.oH.x, wedge.corners.oH.y, 'oH', style='italic', bbox={'facecolor': 'red', 'pad': 2})
+                                # ax.text(wedge.corners.iLA.x, wedge.corners.iLA.y, 'iLA', style='italic', bbox={'facecolor': 'red', 'pad': 2})
+                                # ax.text(wedge.corners.oLA.x, wedge.corners.oLA.y, 'oLA', style='italic', bbox={'facecolor': 'red', 'pad': 2})
+                                # if blocks.index(block_key) == 0:
+                                #     corners1 = block.block_corners
+                                #     corners2 = adj_winding.blocks[adj_blocks[0]].block_corners
+                                # else:
+                                #     corners2 = block.block_corners
+                                #     corners1 = adj_winding.blocks[adj_blocks[blocks.index(block_key)]].block_corners
+                                #
+                                # if corners1.iLA.y >= 0.:
+                                #     wedge.corners = pd.Corner(iH=corners2.iLA, iLA=corners1.iH,
+                                #                               oH=corners2.oLA, oLA=corners1.oH)
+                                # else:
+                                #     wedge.corners = pd.Corner(iH=corners1.iLA, iLA=corners2.iH,
+                                #                               oH=corners1.oLA, oLA=corners2.oH)
 
                                 wedge.corrected_center = pd.CenterShift()
-                                inner, outer = arcCenter(C=coil.bore_center, iL=wedge.corners.iL, iR=wedge.corners.iR,
-                                                         oL=wedge.corners.oL, oR=wedge.corners.oR)
+                                if wedge.corners.iLA.y >= 0.:
+                                    inner, outer = arcCenter(C=coil.bore_center, iH=wedge.corners.iH, iLA=wedge.corners.iLA,
+                                                             oH=wedge.corners.oH, oLA=wedge.corners.oLA)
+                                else:
+                                    inner, outer = arcCenter(C=coil.bore_center, iH=wedge.corners.iLA, iLA=wedge.corners.iH,
+                                                             oH=wedge.corners.oLA, oLA=wedge.corners.oH)
                                 wedge.corrected_center.inner = pd.Coord(x=float(sigDig(inner[0])),
                                                                         y=float(sigDig(inner[1])))
                                 wedge.corrected_center.outer = pd.Coord(x=float(sigDig(outer[0])),
                                                                         y=float(sigDig(outer[1])))
+                                # ax.text(wedge.corrected_center.inner.x, wedge.corrected_center.inner.y, 'i' + str(wedge_no), style='italic', bbox={'facecolor': 'blue', 'pad': 2})
+                                # ax.text(wedge.corrected_center.outer.x, wedge.corrected_center.outer.y, 'o' + str(wedge_no), style='italic', bbox={'facecolor': 'blue', 'pad': 2})
 
-        return self.data.wedges
+        return self.data if coil else self.data.wedges
 
     def getData(self, dir_iron: Path = None, dir_data: Path = None, dir_cadata: Path = None,
                 dump_yamls: bool = False, verbose: bool = False):
@@ -1626,14 +1649,14 @@ class ParserRoxie:
 
             # Acquire coil data from the .data Roxie file
             self.dir_data = dir_data
-            self.getCoilDataFromDataFile(verbose=verbose)
+            self.getCoilDataFromDataFile(verbose=verbose)  # TODO: alternatively, allow to read coil data from DataBuilderMagnet keys
 
             # Save raw data from original Roxie files
             if dump_yamls:
                 with open('raw_data.yaml', 'w') as yaml_file:
                     yaml.dump(self.rawData.dict(), yaml_file, default_flow_style=False)
 
-            # Apply simmetry conditions and transformations to the original winding blocks
+            # Apply symmetry conditions and transformations to the original winding blocks
             self.roxieData = self.rawData
             self.applySymmetryConditions(verbose=verbose)
             self.applyTransformations(verbose=verbose)
