@@ -114,6 +114,19 @@ class ParserXYCE:
                     self.circuit_data.InitialConditions.initial_conditions[str(name)] = str(value)
                     continue
 
+                # Read options
+                if '.OPTION' in line:  # it also covers the case where ".OPTIONS" is written
+                    self.flag_read_options = True
+                    self.circuit_data.Options.options_simulation = {}
+                    continue
+                if self.flag_read_options and '+ ' in line:
+                    line_split = line.rstrip('\n').strip(' ').split(' ')
+                    line_split = line_split[1].split('=')
+                    name  = line_split[0].strip('"')
+                    value = line_split[1].strip('{').strip('}')
+                    self.circuit_data.Options.options_simulation[str(name)] = str(value)
+                    continue
+
                 # Read analysis
                 if '.TRAN' in line:
                     self.circuit_data.Analysis.analysis_type = 'transient'
@@ -472,6 +485,39 @@ class ParserXYCE:
             else:
                 raise Exception ('Netlist entry {} in position #{} has an unknown type: {}.'.format(name, s+1, type))
 
+        # Prepare options - Simulation options
+        rows_options = []
+        options = self.circuit_data.Options.options_simulation
+
+        keywords_timeInt = ['METHOD', 'RELTOL', 'ABSTOL', 'RESTARTSTEPSCALE'] # Not complete list, but most used
+        keywords_NonLinSolv = ['NLSTRATEGY', 'SEARCHMETHOD', 'CONTINUATION', 'RELTOL', 'ABSTOL', 'DELTAXTOL', 'RHSTOL']
+        keywords_LinSolv = ['type']
+
+        if options:
+            # Add comment and .OPTIONS command before the first entry
+            rows_options.append(add_comment('**** Simulation parameters ****'))  # Add header of this section
+
+            overlap_timeInt = [i for i in keywords_timeInt if i in list(options.keys())]
+            overlap_NonLinSolv = [i for i in keywords_NonLinSolv if i in list(options.keys())]
+            overlap_LinSolv = [i for i in keywords_LinSolv if i in list(options.keys())]
+
+            if overlap_timeInt:
+                rows_options.append('.OPTIONS TIMEINT')  # Add header of this section
+                # Add option entries
+                for name in overlap_timeInt:
+                    rows_options.append(add_option(name, options[name]))
+            if overlap_NonLinSolv:
+                rows_options.append('.OPTIONS NONLIN')  # Add header of this section
+                # Add option entries
+                for name in overlap_NonLinSolv:
+                    rows_options.append(add_option(name, options[name]))
+            if overlap_LinSolv:
+                rows_options.append('.OPTIONS LINSOL')  # Add header of this section
+                # Add option entries
+                for name in overlap_LinSolv:
+                    rows_options.append(add_option(name, options[name]))
+
+
         # Prepare analysis settings
         rows_analysis = []
         analysis_type = self.circuit_data.Analysis.analysis_type
@@ -539,6 +585,7 @@ class ParserXYCE:
             rows_global_parameters + \
             rows_initial_conditions + \
             rows_netlist + \
+            rows_options + \
             rows_analysis + \
             rows_post_processing + \
             rows_file_end
@@ -724,12 +771,17 @@ def add_pulsed_source_component(name: str, nodes: list, value: str):
     formatted_text = name + ' ' + str_nodes + ' ' + str_stimulus
     return formatted_text
 
+def add_option(name: str, value: str):
+    ''' Format option row '''
+    formatted_text = '+ ' + name + '=' + value
+    return formatted_text
+
 
 def add_transient_source_component(name: str, nodes: list, value: str):
     ''' Format controlled-source component netlist row '''
     str_nodes = " ".join(nodes)  # string with space-separated nodes
     str_stimulus = 'AC ' + '{' + value + '}'
-    formatted_text = name + ' (' + str_nodes + ') ' + str_stimulus
+    formatted_text = name + ' ' + str_nodes + ' ' + str_stimulus
     return formatted_text
 
 
