@@ -1,6 +1,7 @@
 import os
 from pathlib import Path
 import yaml
+import ruamel.yaml
 from steam_sdk.data.DataModelMagnet import DataModelMagnet
 from steam_sdk.parsers.ParserYAML import dict_to_yaml
 
@@ -11,14 +12,17 @@ if __name__ == "__main__":
     models = [x.parts[-1] for x in Path(path_models).iterdir() if x.is_dir()]
     #models = ['MCBRD']
 
-    for mm in models:
+    for mm in ['MB_2COILS']:#models:
         # Read file
         file_model_data = Path.joinpath(path_models, mm, 'input', 'modelData_' + mm + '.yaml')
         if os.path.isfile(file_model_data):
             # Load yaml keys into DataAnalysis dataclass
             with open(file_model_data, "r") as stream:
-                dictionary_yaml = yaml.safe_load(stream)
-                model_data = DataModelMagnet(**dictionary_yaml)
+                dictionary_yaml = ruamel.yaml.round_trip_load(stream)
+            with open(file_model_data, "r") as stream:
+                dictionary_yaml_without_comments = yaml.safe_load(stream)
+            model_data = DataModelMagnet(**dictionary_yaml)  # TODO here we're ignoring any comment present in the file and forgetting about them
+            model_data_without_comments = DataModelMagnet(**dictionary_yaml_without_comments)  # TODO here we're ignoring any comment present in the file and forgetting about them
             print(f'Read file: {file_model_data}')
 
             # Note: Obsolete keys in yaml file will automatically be deleted
@@ -47,12 +51,14 @@ if __name__ == "__main__":
 
             # Check and reformat the key values
             model_data = DataModelMagnet(**model_data.dict())
+            model_data_without_comments = DataModelMagnet(**model_data_without_comments.dict())
 
             # Write file
             # file_model_data_output = Path.joinpath(path_models, mm, 'input', 'modelData_' + mm + '_MODIFIED.yaml')  # use this line if you wish to test the results of this script
             file_model_data_output = file_model_data  # use this line if you wish to really update all yaml input files
             all_data_dict = {**model_data.dict()}
-            dict_to_yaml(all_data_dict, file_model_data_output, list_exceptions=['Conductors'])
+            all_data_dict_without_comments = {**model_data_without_comments.dict()}
+            dict_to_yaml(all_data_dict, file_model_data_output, list_exceptions=['Conductors'], with_comments=True)
             print(f'Written file: {file_model_data_output}')
         else:
             print(f'WARNING: File {file_model_data} not found.')
