@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from typing import List
+from typing import List, Union
 import numpy as np
 import pandas as pd
 import yaml
@@ -13,13 +13,13 @@ import matplotlib.pyplot as plt
 from steam_sdk.parsers.ParserMat import get_signals_from_mat
 from steam_sdk.parsers.ParserCsv import get_signals_from_csv
 from steam_sdk.parsers.ParserCsd import get_signals_from_csd
+from steam_sdk.parsers.ParserPdf import ParserPdf
 from steam_sdk.parsers.ParserTdms import ParserTdms
 from steam_sdk.utils.make_folder_if_not_existing import make_folder_if_not_existing
 from steam_sdk.utils.unique import unique
 from steam_sdk.utils.isNaN import isNaN
 
 
-
 class Viewer:
     """
         Class with methods to read and view simulation files
@@ -30,6 +30,9 @@ class Viewer:
                  flag_analyze: bool = True,
                  flag_display: bool = False,
                  flag_save_figures: bool = False,
+                 path_output_html_report: str = None,
+                 path_output_pdf_report: str = None,
+                 figure_types: Union[List[str], str] = 'png',
                  verbose: bool = False):
         '''
             Initialization using the paths to the simulation data
@@ -39,6 +42,8 @@ class Viewer:
             :param flag_analyze: if flag_analyze=True, run the analysis directly during the object initialization
             :param flag_display: If flag_display=True, the figures will be displayed
             :param flag_save_figures: if flag_save_figures=True, figures will be saved in the figure output folder defined in the input file
+            :param flag_save_html_report: if flag_save_html_report=True, a report will be generated using the generated figures
+            :param figure_types: List of figure types. All selected figure types will be written
             :param verbose: If verbose=True, additional information will be displayed during the run
 
             TO BE CONSIDERED TO ADD
@@ -54,11 +59,18 @@ class Viewer:
         self.verbose = verbose
         self.flag_display = flag_display
         self.flag_save_figures = flag_save_figures
+        self.path_output_html_report = path_output_html_report
+        self.path_output_pdf_report = path_output_pdf_report
         self.file_name_transients = file_name_transients
+        if figure_types:
+            self.figure_types = figure_types
+        else:
+            self.figure_types = 'png'
 
         # Initialize empty variables
         self.dict_configs = {}  # this dictionary will contain all configurations, which define which measured and simulated signals are acquired
         self.dict_data    = {}  # this dictionary will contain all event data. Each event includes a combination of measured data, simulated data, or both, including multipliers
+        self.dict_figures = {}  # this dictionary will contain as many keys as the events, and each key will contain a list with the paths of all generated figures
 
         # Initialize by reading the input file
         if self.verbose:
@@ -147,12 +159,15 @@ class Viewer:
         for t in list_events:
             # event_label = dict_events['Event label'][t-1]
 
-            # Get flag indicating whether the measurement file should be converted to csv
+            # get flag indicating whether the measurement file should be converted to csv & check if it is valid
             flag_convert_meas_csv = dict_events['flag_convert_meas_csv'][t-1]
+            if flag_convert_meas_csv not in [0, 1, 2] and not pd.isna(flag_convert_meas_csv):
+                raise Exception(f'Invalid parameter. flag_convert_meas_csv can either be 0, 1, 2 or empty in Viewer input file.')
 
+            # if flag_convert_meas_csv=0, the file of this event will not be converted: go to the next event
             if flag_convert_meas_csv == 0 or isNaN(flag_convert_meas_csv):
                 if verbose: print(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file not converted to csv.')
-                continue  # if flag_convert_meas_csv=0, the file of this event will not be converted: go to the next event
+                continue
 
             # Identify measurement file
             measurement_folder = dict_events['Measurement folder'][t-1]
@@ -172,7 +187,7 @@ class Viewer:
             configuration_name = dict_events['Configuration'][t-1]
             configuration      = dict_configs[configuration_name]
 
-            for signal in configuration.SignalList:
+            for _, signal in configuration.SignalList.items():
                 meas_signals_to_add = signal.meas_signals_to_add_x + signal.meas_signals_to_add_y
                 for s, _ in enumerate(meas_signals_to_add):
                     group_name = meas_signals_to_add[s].split('.')[0]  # group where the current signal is located
@@ -180,12 +195,26 @@ class Viewer:
             requested_groups = unique(requested_groups)  # Delete elements that appear twice in these two lists
             if verbose: print(f'Row {t}: Requested groups: {requested_groups}.')
 
-            # Check that the measurement file exists
+            def find_file(file_name, folder):
+                for root, dirs, files in os.walk(folder):
+                    if file_name in files:
+                        return os.path.join(root, file_name)
+                return None
+
+            # Check that the measurement file exists in the measurement folder and all of its sub-folders
             full_path_meas_file     = Path(os.path.join(measurement_folder, campaign, meas + '.tdms')).resolve()
             path_meas_csv_folder    = Path(os.path.join(path_output_measurement_files, campaign)).resolve()  # each subfolder in this folder represents a test campaign
             full_path_meas_csv_file = Path(os.path.join(path_meas_csv_folder, meas + '.csv')).resolve()
             if not os.path.isfile(full_path_meas_file):
-                raise Exception(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file {full_path_meas_file} not found.')
+                # if file is not in right campaign folder, search file in other campaign folders
+                filename = meas + '.tdms'
+                full_path_meas_file = find_file(filename, measurement_folder)
+                if full_path_meas_file is None:
+                    # raise Exception if the file cannot be found in any other campaign folder
+                    raise Exception(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file {filename} not found in any campaign.')
+                else:
+                    print(f'File {filename} was not in the expected campaign folder {campaign}. Could, however, be found at: {full_path_meas_file}')
+                    print(f'Converted csv file will be stored in the expected campaign folder {campaign}.')
 
             # Convert the requested groups of the .tdms file to separate .csv files
             if flag_convert_meas_csv == 1:
@@ -204,10 +233,13 @@ class Viewer:
         :return: None
         '''
         # Unpack inputs
-        verbose = self.verbose
-        dict_configs = self.dict_configs
-        dict_events = self.dict_events
-        list_events = self.list_events
+        verbose                 = self.verbose
+        dict_configs            = self.dict_configs
+        dict_events             = self.dict_events
+        list_events             = self.list_events
+        figure_types            = self.figure_types
+        path_output_html_report = self.path_output_html_report
+        path_output_pdf_report  = self.path_output_pdf_report
 
 
         if verbose: print('### Perform analysis. ###')
@@ -227,8 +259,15 @@ class Viewer:
             measurement_folder            = dict_events['Measurement folder'][t-1]
             campaign                      = dict_events['Test campaign'][t-1]
             meas                          = dict_events['Test name'][t-1]
+            # check inputs
+            if any([var is None for var in [meas, campaign]]):
+                raise Exception(f"Test Name and Test Campaign of {event_label} have to be provided in Viewer input file.")
+            # skip row if no measurement file is provided:
+            if campaign == 'CorrespondingCampaignNotFound':
+                if verbose: print(f'Skipping event {event_label}. No measurement Data could be found in specified directories.')
+                continue
             temp_dict_meas = {}
-            for signal in configuration.SignalList:  # a signal can include multiple meas, sim, or both signals/channels
+            for _, signal in configuration.SignalList.items():  # a signal can include multiple meas, sim, or both signals/channels
                 meas_signals_to_add = signal.meas_signals_to_add_x + signal.meas_signals_to_add_y
                 for s, _ in enumerate(meas_signals_to_add):
                     group_name  = meas_signals_to_add[s].split('.')[0]  # group where the current signal is located
@@ -261,7 +300,7 @@ class Viewer:
 
                 # Identify simulation signals and time vectors required for this event
                 signal_list_sim = []
-                for signal in configuration.SignalList:
+                for _, signal in configuration.SignalList.items():
                     if (len(signal.sim_signals_to_add_x) > 0) and (len(signal.sim_signals_to_add_y) > 0):
                         signal_list_sim = signal_list_sim + signal.sim_signals_to_add_x + signal.sim_signals_to_add_y
                 # Delete elements that appear twice in these two lists
@@ -285,7 +324,8 @@ class Viewer:
 
 
             # Calculate the desired measured and simulated signals by combining the acquired channels and accounting for the selected multipliers
-            for signal in configuration.SignalList:  # a signal can include multiple meas, sim, or both signals/channels
+            self.dict_figures[event_label] = []  # This list will contain the paths of all generated figures
+            for sig_name, signal in configuration.SignalList.items():  # a signal can include multiple meas, sim, or both signals/channels
                 # Measured signal
                 meas_signals_to_add_x = signal.meas_signals_to_add_x
                 meas_signals_to_add_y = signal.meas_signals_to_add_y
@@ -324,9 +364,9 @@ class Viewer:
                 # Plot current signal (meas, or sim, or both) of the current event
                 path_output_figures = Path(dict_events['path_output_figures'][t-1]).resolve()
                 if self.flag_save_figures:
-                    fig_name    = signal.name
-                    figure_name = f'{event_label}_{fig_name}.png'
-                    full_path_figure_to_save = os.path.join(path_output_figures, figure_name)
+                    fig_name    = sig_name
+                    figure_name = f'{event_label}_{fig_name}'  # note that the file extension is missing
+                    full_path_figure_to_save = os.path.join(path_output_figures, event_label, figure_name)  # note that the file extension is missing
                     if verbose: print(f'Figure {full_path_figure_to_save} will be saved.')
                     fig_options = {
                         'fig_title':   signal.fig_title,
@@ -335,15 +375,25 @@ class Viewer:
                         'fig_range_x': signal.fig_range_x,
                         'fig_range_y': signal.fig_range_y,
                     }
+                    self.dict_figures[event_label].append(figure_name)
 
                 else:
                     full_path_figure_to_save = None
-                self.plot_signal(event_label, meas_label, sim_label, fig_options, self.flag_display, full_path_figure_to_save)
+                self.plot_signal(event_label, meas_label, sim_label, fig_options, self.flag_display, full_path_figure_to_save, figure_types=figure_types)
 
-                ## TODO Analyze metrics
+        if path_output_html_report:
+            if verbose:
+                print('Html report generation started.')
+            self.make_html_report(path_output_html_report)  # TODO Known issue: in order for the figures to be displayed correctly, they all need to be in subfolders of the same folder, and the path of the html file needs correspond to it
+
+        if path_output_pdf_report:
+            if verbose:
+                print('Pdf report generation started.')
+            self.make_pdf_report(path_output_pdf_report)
+        ## TODO Analyze metrics
 
 
-    def plot_signal(self, event_label: str, meas_label: str, sim_label: str, fig_options: dict, flag_display: bool = True, full_path_figure_to_save: str = None):
+    def plot_signal(self, event_label: str, meas_label: str, sim_label: str, fig_options: dict, flag_display: bool = True, full_path_figure_to_save: str = None, figure_types: Union[List[str], str] = 'png'):
         '''
         # Plot a selected signal (meas, or sim, or both) of a selected event
         :param event_label: Name identifying the event to plot
@@ -357,8 +407,10 @@ class Viewer:
                             - fig_range_y: Pair of float defining the y plot range
         :param flag_display: If flag_display=True, the figure is displayed (they can still be saved)
         :param full_path_figure_to_save: Full path of the desired output figure. If None, the figure is not saved
-        :return: Handles to the figure and its axis
+        :param figure_types: List of figure types. All selected figure types will be written
+        :return: None
         '''
+
         # If the output folder does not exist, make it now
         make_folder_if_not_existing(os.path.dirname(full_path_figure_to_save))
 
@@ -375,6 +427,9 @@ class Viewer:
         if ('fig_label_y' in fig_options): fig_label_y = fig_options['fig_label_y']
         if ('fig_range_x' in fig_options): fig_range_x = np.array(fig_options['fig_range_x'], dtype=np.float32)
         if ('fig_range_y' in fig_options): fig_range_y = np.array(fig_options['fig_range_y'], dtype=np.float32)
+        # Check inputs
+        if type(figure_types) == str:
+            figure_types = [figure_types]
 
         # Set plot properties
         selectedFont = {'fontname': 'DejaVu Sans', 'size': 14}
@@ -382,6 +437,8 @@ class Viewer:
 
         # Plot - Circuit current
         if flag_display:
+            matplotlib.use('TkAgg')  # to display figures default backend is needed
+        else:
             matplotlib.use('Agg')  # using Agg backend so that figures will not be displayed when not wanted
         fig, ax = plt.subplots(1, 1, figsize=default_figsize)
         if meas_label:
@@ -389,7 +446,7 @@ class Viewer:
         if sim_label:
             plt.plot(x_sim,  y_sim,  '-',  linewidth=1.0, color='b', label=sim_label)
         # Set figure options
-        if fig_title:   plt.title(   fig_title, **selectedFont)
+        if fig_title:   plt.title(fig_title, **selectedFont)
         if fig_label_x: plt.xlabel(fig_label_x, **selectedFont)
         if fig_label_y: plt.ylabel(fig_label_y, **selectedFont)
         if len(fig_range_x) == 2: plt.xlim(fig_range_x)
@@ -398,15 +455,11 @@ class Viewer:
         plt.legend(loc='best')
         # plt.tight_layout()
         if full_path_figure_to_save:
-            plt.savefig(full_path_figure_to_save, format='png')  # Save figure
+            # fig.savefig(full_path_figure_to_save, format='png')  # Save figure
+            [fig.savefig(f'{full_path_figure_to_save}.{d_type}', format=d_type) for d_type in figure_types]
         if flag_display:
-            plt.show(block=True)  # show this figure
-        else:
-            plt.plot(block=False)
-            fig.clf()
-            plt.clf()  # clears the figure with all the axis in it (leaves window still open)
-            plt.close()  # closes the window
-        # return fig, ax   # NOTE: return value not needed... if needed figure has to be cleared at one time
+            plt.show()  # block=True show this figure
+        # return fig, ax   # NOTE: return value not needed... if yes -> figure has to be cleared at one time
 
 
     # def plot_ViewerSim(self, data, titles, labels, types, texts, size, legends, style, window, scale, order):
@@ -416,6 +469,108 @@ class Viewer:
     #     self.PM.plotterModel(data, titles, labels, types, texts, size, legends, style, window, scale, order)
 
 
+    def make_html_report(self, path_html_report: str = None):
+        '''
+        Generate an html report using the generated figures
+        :return:
+        '''
+        # If output folder is missing, make it
+        make_folder_if_not_existing(os.path.dirname(path_html_report))
+
+        order_of_preference_figure_type = ['svg', 'png']
+        fig_width = 700
+
+        # Add html start
+        html = \
+    f'''
+    <html>
+    '''
+        # Add file title and introduction
+        html = html + \
+        f'''        
+        <head>
+            <title>Report generted with STEAM-SDK</title>
+        </head>
+            <body>
+                <h1>Report generted with STEAM-SDK</h1>
+                <p>STEAM, CERN, Geneva, CH</p>
+                <hr>
+                <hr>
+            </body>
+        '''
+
+        # Loop through all events
+        for t in self.list_events:
+            event_label = self.dict_events['Event label'][t-1]
+
+            # Add figures
+            for fig_name in self.dict_figures[event_label]:
+                current_path_output_figure = Path(self.dict_events['path_output_figures'][t-1]).resolve()
+                for d_type in order_of_preference_figure_type:
+                    if os.path.isfile(os.path.join(current_path_output_figure, event_label, f'{fig_name}.{d_type}')):  # check if the figures exist
+                        fig_path = os.path.join(event_label, f'{fig_name}.{d_type}')  # Write relative path
+                        break
+
+                html = html + \
+            f'''
+            <body>
+                <h1>{event_label}</h1>
+                <p>{fig_name}</p>
+                <img src='{fig_path}' width="{fig_width}">
+            </body>
+            '''
+            html = html + \
+        f'''
+        <body>
+            <hr>
+        <body>
+        '''
+        # Add html end
+        html = html +\
+    f'''
+    </html>
+    '''
+
+        # Write the html string as an HTML file
+        with open(path_html_report, 'w') as f:
+            f.write(html)
+
+        if self.verbose:
+            print(f'Report file {os.path.abspath(path_html_report)} generated.')
+
+
+    def make_pdf_report(self, path_pdf_report: str = None, default_width: float = None, default_height: float = None):
+        '''
+        Generate a pdf report using the generated figures
+        :return:
+        '''
+        # If output folder is missing, make it
+        make_folder_if_not_existing(os.path.dirname(path_pdf_report))
+
+        order_of_preference_figure_type = ['png']  # hard-coded
+
+        # Start the pdf file
+        ppdf = ParserPdf(path_pdf_report)
+
+        # Loop through all events
+        for t in self.list_events:
+            event_label = self.dict_events['Event label'][t-1]
+
+            # Add figures
+            for fig_name in self.dict_figures[event_label]:
+                current_path_output_figure = Path(self.dict_events['path_output_figures'][t-1]).resolve()
+                for d_type in order_of_preference_figure_type:
+                    if os.path.isfile(os.path.join(current_path_output_figure, event_label, f'{fig_name}.{d_type}')):  # check if the figures exist
+                        fig_path = os.path.join(current_path_output_figure, event_label, f'{fig_name}.{d_type}')  # Write relative path
+                        break
+                ppdf.add_image(fig_path)
+                ppdf.add_page_break()
+
+        # Write pdf
+        ppdf.generate_pdf()
+
+        if self.verbose:
+            print(f'Report file {os.path.abspath(path_pdf_report)} generated.')
 
 
     # Helper functions
